from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_profile_list_response_pagination_extensions import RuntimeProfileListResponsePaginationExtensions





T = TypeVar("T", bound="RuntimeProfileListResponsePagination")



@_attrs_define
class RuntimeProfileListResponsePagination:
    """ 
        Attributes:
            extensions (RuntimeProfileListResponsePaginationExtensions | Unset): Optional vendor extension map. Keys must be
                namespaced as <reverse_dns_or_org>.<key>.
            next_page_token (str | Unset):
            page_size (int | Unset):
     """

    extensions: RuntimeProfileListResponsePaginationExtensions | Unset = UNSET
    next_page_token: str | Unset = UNSET
    page_size: int | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_profile_list_response_pagination_extensions import RuntimeProfileListResponsePaginationExtensions
        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        next_page_token = self.next_page_token

        page_size = self.page_size


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if next_page_token is not UNSET:
            field_dict["next_page_token"] = next_page_token
        if page_size is not UNSET:
            field_dict["page_size"] = page_size

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_profile_list_response_pagination_extensions import RuntimeProfileListResponsePaginationExtensions
        d = dict(src_dict)
        _extensions = d.pop("extensions", UNSET)
        extensions: RuntimeProfileListResponsePaginationExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RuntimeProfileListResponsePaginationExtensions.from_dict(_extensions)




        next_page_token = d.pop("next_page_token", UNSET)

        page_size = d.pop("page_size", UNSET)

        runtime_profile_list_response_pagination = cls(
            extensions=extensions,
            next_page_token=next_page_token,
            page_size=page_size,
        )

        return runtime_profile_list_response_pagination




""" Contains all the data models used in inputs/outputs """

from .error_envelope import ErrorEnvelope
from .error_envelope_error import ErrorEnvelopeError
from .error_envelope_error_details import ErrorEnvelopeErrorDetails
from .error_envelope_error_error_cause import ErrorEnvelopeErrorErrorCause
from .error_envelope_error_error_cause_details import ErrorEnvelopeErrorErrorCauseDetails
from .error_envelope_error_error_cause_extensions import ErrorEnvelopeErrorErrorCauseExtensions
from .error_envelope_error_extensions import ErrorEnvelopeErrorExtensions
from .error_envelope_extensions import ErrorEnvelopeExtensions
from .health import Health
from .health_checks_item import HealthChecksItem
from .health_checks_item_details import HealthChecksItemDetails
from .health_checks_item_status import HealthChecksItemStatus
from .health_extensions import HealthExtensions
from .health_status import HealthStatus
from .tool_definition import ToolDefinition
from .tool_definition_extensions import ToolDefinitionExtensions
from .tool_definition_input_schema import ToolDefinitionInputSchema
from .tool_definition_metadata import ToolDefinitionMetadata
from .tool_definition_metadata_annotations import ToolDefinitionMetadataAnnotations
from .tool_definition_metadata_extensions import ToolDefinitionMetadataExtensions
from .tool_definition_metadata_labels import ToolDefinitionMetadataLabels
from .tool_definition_output_schema import ToolDefinitionOutputSchema
from .tool_definition_source import ToolDefinitionSource
from .tool_invocation_result import ToolInvocationResult
from .tool_invocation_result_error import ToolInvocationResultError
from .tool_invocation_result_error_details import ToolInvocationResultErrorDetails
from .tool_invocation_result_error_error_cause import ToolInvocationResultErrorErrorCause
from .tool_invocation_result_error_error_cause_details import ToolInvocationResultErrorErrorCauseDetails
from .tool_invocation_result_error_error_cause_extensions import ToolInvocationResultErrorErrorCauseExtensions
from .tool_invocation_result_error_extensions import ToolInvocationResultErrorExtensions
from .tool_invocation_result_extensions import ToolInvocationResultExtensions
from .tool_invocation_result_result import ToolInvocationResultResult
from .version_info import VersionInfo
from .version_info_build import VersionInfoBuild
from .version_info_extensions import VersionInfoExtensions

__all__ = (
    "ErrorEnvelope",
    "ErrorEnvelopeError",
    "ErrorEnvelopeErrorDetails",
    "ErrorEnvelopeErrorErrorCause",
    "ErrorEnvelopeErrorErrorCauseDetails",
    "ErrorEnvelopeErrorErrorCauseExtensions",
    "ErrorEnvelopeErrorExtensions",
    "ErrorEnvelopeExtensions",
    "Health",
    "HealthChecksItem",
    "HealthChecksItemDetails",
    "HealthChecksItemStatus",
    "HealthExtensions",
    "HealthStatus",
    "ToolDefinition",
    "ToolDefinitionExtensions",
    "ToolDefinitionInputSchema",
    "ToolDefinitionMetadata",
    "ToolDefinitionMetadataAnnotations",
    "ToolDefinitionMetadataExtensions",
    "ToolDefinitionMetadataLabels",
    "ToolDefinitionOutputSchema",
    "ToolDefinitionSource",
    "ToolInvocationResult",
    "ToolInvocationResultError",
    "ToolInvocationResultErrorDetails",
    "ToolInvocationResultErrorErrorCause",
    "ToolInvocationResultErrorErrorCauseDetails",
    "ToolInvocationResultErrorErrorCauseExtensions",
    "ToolInvocationResultErrorExtensions",
    "ToolInvocationResultExtensions",
    "ToolInvocationResultResult",
    "VersionInfo",
    "VersionInfoBuild",
    "VersionInfoExtensions",
)



""" Contains all the data models used in inputs/outputs """

from .error_envelope import ErrorEnvelope
from .error_envelope_error import ErrorEnvelopeError
from .error_envelope_error_details import ErrorEnvelopeErrorDetails
from .error_envelope_error_error_cause import ErrorEnvelopeErrorErrorCause
from .error_envelope_error_error_cause_details import ErrorEnvelopeErrorErrorCauseDetails
from .error_envelope_error_error_cause_extensions import ErrorEnvelopeErrorErrorCauseExtensions
from .error_envelope_error_extensions import ErrorEnvelopeErrorExtensions
from .error_envelope_extensions import ErrorEnvelopeExtensions
from .health import Health
from .health_checks_item import HealthChecksItem
from .health_checks_item_details import HealthChecksItemDetails
from .health_checks_item_status import HealthChecksItemStatus
from .health_extensions import HealthExtensions
from .health_status import HealthStatus
from .instance_create_request import InstanceCreateRequest
from .instance_create_request_extensions import InstanceCreateRequestExtensions
from .instance_create_request_metadata import InstanceCreateRequestMetadata
from .instance_create_request_metadata_annotations import InstanceCreateRequestMetadataAnnotations
from .instance_create_request_metadata_extensions import InstanceCreateRequestMetadataExtensions
from .instance_create_request_metadata_labels import InstanceCreateRequestMetadataLabels
from .instance_create_request_overrides import InstanceCreateRequestOverrides
from .instance_create_request_overrides_env import InstanceCreateRequestOverridesEnv
from .instance_create_response import InstanceCreateResponse
from .instance_create_response_extensions import InstanceCreateResponseExtensions
from .instance_create_response_runtime_instance import InstanceCreateResponseRuntimeInstance
from .instance_create_response_runtime_instance_extensions import InstanceCreateResponseRuntimeInstanceExtensions
from .instance_create_response_runtime_instance_metadata import InstanceCreateResponseRuntimeInstanceMetadata
from .instance_create_response_runtime_instance_metadata_annotations import InstanceCreateResponseRuntimeInstanceMetadataAnnotations
from .instance_create_response_runtime_instance_metadata_extensions import InstanceCreateResponseRuntimeInstanceMetadataExtensions
from .instance_create_response_runtime_instance_metadata_labels import InstanceCreateResponseRuntimeInstanceMetadataLabels
from .instance_create_response_runtime_instance_state import InstanceCreateResponseRuntimeInstanceState
from .instance_list_response import InstanceListResponse
from .instance_list_response_extensions import InstanceListResponseExtensions
from .instance_list_response_runtime_instance import InstanceListResponseRuntimeInstance
from .instance_list_response_runtime_instance_extensions import InstanceListResponseRuntimeInstanceExtensions
from .instance_list_response_runtime_instance_metadata import InstanceListResponseRuntimeInstanceMetadata
from .instance_list_response_runtime_instance_metadata_annotations import InstanceListResponseRuntimeInstanceMetadataAnnotations
from .instance_list_response_runtime_instance_metadata_extensions import InstanceListResponseRuntimeInstanceMetadataExtensions
from .instance_list_response_runtime_instance_metadata_labels import InstanceListResponseRuntimeInstanceMetadataLabels
from .instance_list_response_runtime_instance_state import InstanceListResponseRuntimeInstanceState
from .instance_register_request import InstanceRegisterRequest
from .instance_register_request_extensions import InstanceRegisterRequestExtensions
from .instance_register_request_metadata import InstanceRegisterRequestMetadata
from .instance_register_request_metadata_annotations import InstanceRegisterRequestMetadataAnnotations
from .instance_register_request_metadata_extensions import InstanceRegisterRequestMetadataExtensions
from .instance_register_request_metadata_labels import InstanceRegisterRequestMetadataLabels
from .instance_register_response import InstanceRegisterResponse
from .instance_register_response_extensions import InstanceRegisterResponseExtensions
from .instance_register_response_runtime_instance import InstanceRegisterResponseRuntimeInstance
from .instance_register_response_runtime_instance_extensions import InstanceRegisterResponseRuntimeInstanceExtensions
from .instance_register_response_runtime_instance_metadata import InstanceRegisterResponseRuntimeInstanceMetadata
from .instance_register_response_runtime_instance_metadata_annotations import InstanceRegisterResponseRuntimeInstanceMetadataAnnotations
from .instance_register_response_runtime_instance_metadata_extensions import InstanceRegisterResponseRuntimeInstanceMetadataExtensions
from .instance_register_response_runtime_instance_metadata_labels import InstanceRegisterResponseRuntimeInstanceMetadataLabels
from .instance_register_response_runtime_instance_state import InstanceRegisterResponseRuntimeInstanceState
from .run_list_response import RunListResponse
from .run_list_response_extensions import RunListResponseExtensions
from .run_list_response_pagination import RunListResponsePagination
from .run_list_response_pagination_extensions import RunListResponsePaginationExtensions
from .run_list_response_run_status import RunListResponseRunStatus
from .run_list_response_run_status_extensions import RunListResponseRunStatusExtensions
from .run_list_response_run_status_state import RunListResponseRunStatusState
from .run_request import RunRequest
from .run_request_extensions import RunRequestExtensions
from .run_request_input import RunRequestInput
from .run_request_input_context import RunRequestInputContext
from .run_request_input_data import RunRequestInputData
from .run_request_limits import RunRequestLimits
from .run_request_metadata import RunRequestMetadata
from .run_request_metadata_annotations import RunRequestMetadataAnnotations
from .run_request_metadata_extensions import RunRequestMetadataExtensions
from .run_request_metadata_labels import RunRequestMetadataLabels
from .run_request_runtime_selector import RunRequestRuntimeSelector
from .run_request_tool_policy import RunRequestToolPolicy
from .run_result import RunResult
from .run_result_error import RunResultError
from .run_result_error_details import RunResultErrorDetails
from .run_result_error_error_cause import RunResultErrorErrorCause
from .run_result_error_error_cause_details import RunResultErrorErrorCauseDetails
from .run_result_error_error_cause_extensions import RunResultErrorErrorCauseExtensions
from .run_result_error_extensions import RunResultErrorExtensions
from .run_result_extensions import RunResultExtensions
from .run_result_output import RunResultOutput
from .run_result_resource_ref import RunResultResourceRef
from .run_result_resource_ref_extensions import RunResultResourceRefExtensions
from .run_result_usage import RunResultUsage
from .run_status import RunStatus
from .run_status_extensions import RunStatusExtensions
from .run_status_state import RunStatusState
from .runtime_instance import RuntimeInstance
from .runtime_instance_extensions import RuntimeInstanceExtensions
from .runtime_instance_metadata import RuntimeInstanceMetadata
from .runtime_instance_metadata_annotations import RuntimeInstanceMetadataAnnotations
from .runtime_instance_metadata_extensions import RuntimeInstanceMetadataExtensions
from .runtime_instance_metadata_labels import RuntimeInstanceMetadataLabels
from .runtime_instance_state import RuntimeInstanceState
from .runtime_profile import RuntimeProfile
from .runtime_profile_defaults import RuntimeProfileDefaults
from .runtime_profile_defaults_env import RuntimeProfileDefaultsEnv
from .runtime_profile_extensions import RuntimeProfileExtensions
from .runtime_profile_list_response import RuntimeProfileListResponse
from .runtime_profile_list_response_extensions import RuntimeProfileListResponseExtensions
from .runtime_profile_list_response_pagination import RuntimeProfileListResponsePagination
from .runtime_profile_list_response_pagination_extensions import RuntimeProfileListResponsePaginationExtensions
from .runtime_profile_list_response_runtime_profile import RuntimeProfileListResponseRuntimeProfile
from .runtime_profile_list_response_runtime_profile_defaults import RuntimeProfileListResponseRuntimeProfileDefaults
from .runtime_profile_list_response_runtime_profile_defaults_env import RuntimeProfileListResponseRuntimeProfileDefaultsEnv
from .runtime_profile_list_response_runtime_profile_extensions import RuntimeProfileListResponseRuntimeProfileExtensions
from .runtime_profile_list_response_runtime_profile_metadata import RuntimeProfileListResponseRuntimeProfileMetadata
from .runtime_profile_list_response_runtime_profile_metadata_annotations import RuntimeProfileListResponseRuntimeProfileMetadataAnnotations
from .runtime_profile_list_response_runtime_profile_metadata_extensions import RuntimeProfileListResponseRuntimeProfileMetadataExtensions
from .runtime_profile_list_response_runtime_profile_metadata_labels import RuntimeProfileListResponseRuntimeProfileMetadataLabels
from .runtime_profile_metadata import RuntimeProfileMetadata
from .runtime_profile_metadata_annotations import RuntimeProfileMetadataAnnotations
from .runtime_profile_metadata_extensions import RuntimeProfileMetadataExtensions
from .runtime_profile_metadata_labels import RuntimeProfileMetadataLabels
from .runtime_profile_upsert_request import RuntimeProfileUpsertRequest
from .runtime_profile_upsert_request_defaults import RuntimeProfileUpsertRequestDefaults
from .runtime_profile_upsert_request_defaults_env import RuntimeProfileUpsertRequestDefaultsEnv
from .runtime_profile_upsert_request_extensions import RuntimeProfileUpsertRequestExtensions
from .runtime_profile_upsert_request_metadata import RuntimeProfileUpsertRequestMetadata
from .runtime_profile_upsert_request_metadata_annotations import RuntimeProfileUpsertRequestMetadataAnnotations
from .runtime_profile_upsert_request_metadata_extensions import RuntimeProfileUpsertRequestMetadataExtensions
from .runtime_profile_upsert_request_metadata_labels import RuntimeProfileUpsertRequestMetadataLabels
from .trace_response import TraceResponse
from .trace_response_extensions import TraceResponseExtensions
from .trace_response_trace_event import TraceResponseTraceEvent
from .trace_response_trace_event_data import TraceResponseTraceEventData
from .trace_response_trace_event_extensions import TraceResponseTraceEventExtensions
from .trace_response_trace_event_level import TraceResponseTraceEventLevel
from .version_info import VersionInfo
from .version_info_build import VersionInfoBuild
from .version_info_extensions import VersionInfoExtensions

__all__ = (
    "ErrorEnvelope",
    "ErrorEnvelopeError",
    "ErrorEnvelopeErrorDetails",
    "ErrorEnvelopeErrorErrorCause",
    "ErrorEnvelopeErrorErrorCauseDetails",
    "ErrorEnvelopeErrorErrorCauseExtensions",
    "ErrorEnvelopeErrorExtensions",
    "ErrorEnvelopeExtensions",
    "Health",
    "HealthChecksItem",
    "HealthChecksItemDetails",
    "HealthChecksItemStatus",
    "HealthExtensions",
    "HealthStatus",
    "InstanceCreateRequest",
    "InstanceCreateRequestExtensions",
    "InstanceCreateRequestMetadata",
    "InstanceCreateRequestMetadataAnnotations",
    "InstanceCreateRequestMetadataExtensions",
    "InstanceCreateRequestMetadataLabels",
    "InstanceCreateRequestOverrides",
    "InstanceCreateRequestOverridesEnv",
    "InstanceCreateResponse",
    "InstanceCreateResponseExtensions",
    "InstanceCreateResponseRuntimeInstance",
    "InstanceCreateResponseRuntimeInstanceExtensions",
    "InstanceCreateResponseRuntimeInstanceMetadata",
    "InstanceCreateResponseRuntimeInstanceMetadataAnnotations",
    "InstanceCreateResponseRuntimeInstanceMetadataExtensions",
    "InstanceCreateResponseRuntimeInstanceMetadataLabels",
    "InstanceCreateResponseRuntimeInstanceState",
    "InstanceListResponse",
    "InstanceListResponseExtensions",
    "InstanceListResponseRuntimeInstance",
    "InstanceListResponseRuntimeInstanceExtensions",
    "InstanceListResponseRuntimeInstanceMetadata",
    "InstanceListResponseRuntimeInstanceMetadataAnnotations",
    "InstanceListResponseRuntimeInstanceMetadataExtensions",
    "InstanceListResponseRuntimeInstanceMetadataLabels",
    "InstanceListResponseRuntimeInstanceState",
    "InstanceRegisterRequest",
    "InstanceRegisterRequestExtensions",
    "InstanceRegisterRequestMetadata",
    "InstanceRegisterRequestMetadataAnnotations",
    "InstanceRegisterRequestMetadataExtensions",
    "InstanceRegisterRequestMetadataLabels",
    "InstanceRegisterResponse",
    "InstanceRegisterResponseExtensions",
    "InstanceRegisterResponseRuntimeInstance",
    "InstanceRegisterResponseRuntimeInstanceExtensions",
    "InstanceRegisterResponseRuntimeInstanceMetadata",
    "InstanceRegisterResponseRuntimeInstanceMetadataAnnotations",
    "InstanceRegisterResponseRuntimeInstanceMetadataExtensions",
    "InstanceRegisterResponseRuntimeInstanceMetadataLabels",
    "InstanceRegisterResponseRuntimeInstanceState",
    "RunListResponse",
    "RunListResponseExtensions",
    "RunListResponsePagination",
    "RunListResponsePaginationExtensions",
    "RunListResponseRunStatus",
    "RunListResponseRunStatusExtensions",
    "RunListResponseRunStatusState",
    "RunRequest",
    "RunRequestExtensions",
    "RunRequestInput",
    "RunRequestInputContext",
    "RunRequestInputData",
    "RunRequestLimits",
    "RunRequestMetadata",
    "RunRequestMetadataAnnotations",
    "RunRequestMetadataExtensions",
    "RunRequestMetadataLabels",
    "RunRequestRuntimeSelector",
    "RunRequestToolPolicy",
    "RunResult",
    "RunResultError",
    "RunResultErrorDetails",
    "RunResultErrorErrorCause",
    "RunResultErrorErrorCauseDetails",
    "RunResultErrorErrorCauseExtensions",
    "RunResultErrorExtensions",
    "RunResultExtensions",
    "RunResultOutput",
    "RunResultResourceRef",
    "RunResultResourceRefExtensions",
    "RunResultUsage",
    "RunStatus",
    "RunStatusExtensions",
    "RunStatusState",
    "RuntimeInstance",
    "RuntimeInstanceExtensions",
    "RuntimeInstanceMetadata",
    "RuntimeInstanceMetadataAnnotations",
    "RuntimeInstanceMetadataExtensions",
    "RuntimeInstanceMetadataLabels",
    "RuntimeInstanceState",
    "RuntimeProfile",
    "RuntimeProfileDefaults",
    "RuntimeProfileDefaultsEnv",
    "RuntimeProfileExtensions",
    "RuntimeProfileListResponse",
    "RuntimeProfileListResponseExtensions",
    "RuntimeProfileListResponsePagination",
    "RuntimeProfileListResponsePaginationExtensions",
    "RuntimeProfileListResponseRuntimeProfile",
    "RuntimeProfileListResponseRuntimeProfileDefaults",
    "RuntimeProfileListResponseRuntimeProfileDefaultsEnv",
    "RuntimeProfileListResponseRuntimeProfileExtensions",
    "RuntimeProfileListResponseRuntimeProfileMetadata",
    "RuntimeProfileListResponseRuntimeProfileMetadataAnnotations",
    "RuntimeProfileListResponseRuntimeProfileMetadataExtensions",
    "RuntimeProfileListResponseRuntimeProfileMetadataLabels",
    "RuntimeProfileMetadata",
    "RuntimeProfileMetadataAnnotations",
    "RuntimeProfileMetadataExtensions",
    "RuntimeProfileMetadataLabels",
    "RuntimeProfileUpsertRequest",
    "RuntimeProfileUpsertRequestDefaults",
    "RuntimeProfileUpsertRequestDefaultsEnv",
    "RuntimeProfileUpsertRequestExtensions",
    "RuntimeProfileUpsertRequestMetadata",
    "RuntimeProfileUpsertRequestMetadataAnnotations",
    "RuntimeProfileUpsertRequestMetadataExtensions",
    "RuntimeProfileUpsertRequestMetadataLabels",
    "TraceResponse",
    "TraceResponseExtensions",
    "TraceResponseTraceEvent",
    "TraceResponseTraceEventData",
    "TraceResponseTraceEventExtensions",
    "TraceResponseTraceEventLevel",
    "VersionInfo",
    "VersionInfoBuild",
    "VersionInfoExtensions",
)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_profile_list_response_runtime_profile import RuntimeProfileListResponseRuntimeProfile
  from ..models.runtime_profile_list_response_extensions import RuntimeProfileListResponseExtensions
  from ..models.runtime_profile_list_response_pagination import RuntimeProfileListResponsePagination





T = TypeVar("T", bound="RuntimeProfileListResponse")



@_attrs_define
class RuntimeProfileListResponse:
    """ 
        Attributes:
            profiles (list[RuntimeProfileListResponseRuntimeProfile]):
            extensions (RuntimeProfileListResponseExtensions | Unset): Optional vendor extension map. Keys must be
                namespaced as <reverse_dns_or_org>.<key>.
            pagination (RuntimeProfileListResponsePagination | Unset):
     """

    profiles: list[RuntimeProfileListResponseRuntimeProfile]
    extensions: RuntimeProfileListResponseExtensions | Unset = UNSET
    pagination: RuntimeProfileListResponsePagination | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_profile_list_response_runtime_profile import RuntimeProfileListResponseRuntimeProfile
        from ..models.runtime_profile_list_response_extensions import RuntimeProfileListResponseExtensions
        from ..models.runtime_profile_list_response_pagination import RuntimeProfileListResponsePagination
        profiles = []
        for profiles_item_data in self.profiles:
            profiles_item = profiles_item_data.to_dict()
            profiles.append(profiles_item)



        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        pagination: dict[str, Any] | Unset = UNSET
        if not isinstance(self.pagination, Unset):
            pagination = self.pagination.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "profiles": profiles,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if pagination is not UNSET:
            field_dict["pagination"] = pagination

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_profile_list_response_runtime_profile import RuntimeProfileListResponseRuntimeProfile
        from ..models.runtime_profile_list_response_extensions import RuntimeProfileListResponseExtensions
        from ..models.runtime_profile_list_response_pagination import RuntimeProfileListResponsePagination
        d = dict(src_dict)
        profiles = []
        _profiles = d.pop("profiles")
        for profiles_item_data in (_profiles):
            profiles_item = RuntimeProfileListResponseRuntimeProfile.from_dict(profiles_item_data)



            profiles.append(profiles_item)


        _extensions = d.pop("extensions", UNSET)
        extensions: RuntimeProfileListResponseExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RuntimeProfileListResponseExtensions.from_dict(_extensions)




        _pagination = d.pop("pagination", UNSET)
        pagination: RuntimeProfileListResponsePagination | Unset
        if isinstance(_pagination,  Unset):
            pagination = UNSET
        else:
            pagination = RuntimeProfileListResponsePagination.from_dict(_pagination)




        runtime_profile_list_response = cls(
            profiles=profiles,
            extensions=extensions,
            pagination=pagination,
        )

        return runtime_profile_list_response




from __future__ import annotations

from dataclasses import dataclass
from typing import Any, TypeVar, overload

import httpx

from arp_sdk.errors import ArpApiError
from arp_sdk.models import (
    RunRequest,
    RunResult,
    RunStatus,
)

from .api.health import (
    health,
)

from .api.runs import (
    cancel_run,
    create_run,
    get_run_result,
    get_run_status,
    stream_run_events,
)

from .api.version import (
    version,
)

from .client import Client as _LowLevelClient
from .models import ErrorEnvelope as _ErrorEnvelope
from .models import Health, VersionInfo
from .types import Response as _Response
from .types import Unset as _Unset

T = TypeVar("T")

def _coerce_model(value: Any, target: type[T]) -> T:
    if isinstance(value, target):
        return value
    if hasattr(value, "to_dict") and hasattr(target, "from_dict"):
        return target.from_dict(value.to_dict())  # type: ignore[attr-defined]
    if isinstance(value, dict) and hasattr(target, "from_dict"):
        return target.from_dict(value)  # type: ignore[attr-defined]
    raise TypeError(f"Cannot coerce {type(value)} to {target}")

def _raise_for_error_envelope(*, envelope: _ErrorEnvelope, status_code: int | None, raw: Any | None) -> None:
    details: Any | None = None
    if not isinstance(envelope.error.details, _Unset):
        details = envelope.error.details.to_dict()
    raise ArpApiError(
        code=str(envelope.error.code),
        message=str(envelope.error.message),
        details=details,
        status_code=status_code,
        raw=raw,
    )

def _unwrap(response: _Response[Any], *, allow_none: bool = False) -> Any:
    parsed = response.parsed
    if parsed is None:
        if allow_none:
            return None
        raise ArpApiError(
            code="unexpected_empty_response",
            message="API returned an empty response",
            status_code=int(response.status_code),
            raw=response.content,
        )
    if isinstance(parsed, _ErrorEnvelope):
        _raise_for_error_envelope(envelope=parsed, status_code=int(response.status_code), raw=parsed.to_dict())
    return parsed

@dataclass(slots=True)
class CancelRunRequest:
    run_id: str

@dataclass(slots=True)
class CreateRunRequest:
    body: RunRequest

@dataclass(slots=True)
class GetRunResultRequest:
    run_id: str

@dataclass(slots=True)
class GetRunStatusRequest:
    run_id: str

@dataclass(slots=True)
class HealthRequest:
    pass

@dataclass(slots=True)
class StreamRunEventsRequest:
    run_id: str

@dataclass(slots=True)
class VersionRequest:
    pass

class RuntimeClient:
    def __init__(
        self,
        base_url: str | None = None,
        *,
        client: _LowLevelClient | None = None,
        timeout: httpx.Timeout | None = None,
        headers: dict[str, str] | None = None,
        cookies: dict[str, str] | None = None,
        verify_ssl: Any = True,
        follow_redirects: bool = False,
        raise_on_unexpected_status: bool = False,
        httpx_args: dict[str, Any] | None = None,
    ) -> None:
        if client is None:
            if base_url is None:
                raise ValueError("base_url is required when client is not provided")
            client = _LowLevelClient(
                base_url=base_url,
                timeout=timeout,
                headers={} if headers is None else dict(headers),
                cookies={} if cookies is None else dict(cookies),
                verify_ssl=verify_ssl,
                follow_redirects=follow_redirects,
                raise_on_unexpected_status=raise_on_unexpected_status,
                httpx_args={} if httpx_args is None else dict(httpx_args),
            )
        self._client = client

    @property
    def raw_client(self) -> _LowLevelClient:
        return self._client

    @overload
    def cancel_run(self, run_id: str) -> RunStatus: ...

    @overload
    def cancel_run(self, run_id: CancelRunRequest) -> RunStatus: ...

    def cancel_run(self, run_id: CancelRunRequest | str) -> RunStatus:
        value = run_id.run_id if isinstance(run_id, CancelRunRequest) else run_id
        run_id = value
        resp = cancel_run.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return result

    @overload
    def create_run(self, body: RunRequest) -> RunStatus: ...

    @overload
    def create_run(self, body: CreateRunRequest) -> RunStatus: ...

    def create_run(self, body: CreateRunRequest | RunRequest) -> RunStatus:
        payload = body.body if isinstance(body, CreateRunRequest) else body
        resp = create_run.sync_detailed(client=self._client, body=payload)
        result = _unwrap(resp)
        return result

    @overload
    def get_run_result(self, run_id: str) -> RunResult: ...

    @overload
    def get_run_result(self, run_id: GetRunResultRequest) -> RunResult: ...

    def get_run_result(self, run_id: GetRunResultRequest | str) -> RunResult:
        value = run_id.run_id if isinstance(run_id, GetRunResultRequest) else run_id
        run_id = value
        resp = get_run_result.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return result

    @overload
    def get_run_status(self, run_id: str) -> RunStatus: ...

    @overload
    def get_run_status(self, run_id: GetRunStatusRequest) -> RunStatus: ...

    def get_run_status(self, run_id: GetRunStatusRequest | str) -> RunStatus:
        value = run_id.run_id if isinstance(run_id, GetRunStatusRequest) else run_id
        run_id = value
        resp = get_run_status.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return result

    @overload
    def health(self) -> Health: ...

    @overload
    def health(self, request: HealthRequest) -> Health: ...

    def health(self, request: HealthRequest | None = None) -> Health:
        _ = request
        resp = health.sync_detailed(client=self._client)
        return _unwrap(resp)

    @overload
    def stream_run_events(self, run_id: str) -> str: ...

    @overload
    def stream_run_events(self, run_id: StreamRunEventsRequest) -> str: ...

    def stream_run_events(self, run_id: StreamRunEventsRequest | str) -> str:
        value = run_id.run_id if isinstance(run_id, StreamRunEventsRequest) else run_id
        run_id = value
        resp = stream_run_events.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return result

    @overload
    def version(self) -> VersionInfo: ...

    @overload
    def version(self, request: VersionRequest) -> VersionInfo: ...

    def version(self, request: VersionRequest | None = None) -> VersionInfo:
        _ = request
        resp = version.sync_detailed(client=self._client)
        return _unwrap(resp)

__all__ = [
    'RuntimeClient',
    'CancelRunRequest',
    'CreateRunRequest',
    'GetRunResultRequest',
    'GetRunStatusRequest',
    'HealthRequest',
    'StreamRunEventsRequest',
    'VersionRequest',
]



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.error_envelope_error_error_cause_details import ErrorEnvelopeErrorErrorCauseDetails
  from ..models.error_envelope_error_error_cause_extensions import ErrorEnvelopeErrorErrorCauseExtensions





T = TypeVar("T", bound="ErrorEnvelopeErrorErrorCause")



@_attrs_define
class ErrorEnvelopeErrorErrorCause:
    """ 
        Attributes:
            message (str):
            code (str | Unset):
            details (ErrorEnvelopeErrorErrorCauseDetails | Unset):
            extensions (ErrorEnvelopeErrorErrorCauseExtensions | Unset): Optional vendor extension map. Keys must be
                namespaced as <reverse_dns_or_org>.<key>.
     """

    message: str
    code: str | Unset = UNSET
    details: ErrorEnvelopeErrorErrorCauseDetails | Unset = UNSET
    extensions: ErrorEnvelopeErrorErrorCauseExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.error_envelope_error_error_cause_details import ErrorEnvelopeErrorErrorCauseDetails
        from ..models.error_envelope_error_error_cause_extensions import ErrorEnvelopeErrorErrorCauseExtensions
        message = self.message

        code = self.code

        details: dict[str, Any] | Unset = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "message": message,
        })
        if code is not UNSET:
            field_dict["code"] = code
        if details is not UNSET:
            field_dict["details"] = details
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.error_envelope_error_error_cause_details import ErrorEnvelopeErrorErrorCauseDetails
        from ..models.error_envelope_error_error_cause_extensions import ErrorEnvelopeErrorErrorCauseExtensions
        d = dict(src_dict)
        message = d.pop("message")

        code = d.pop("code", UNSET)

        _details = d.pop("details", UNSET)
        details: ErrorEnvelopeErrorErrorCauseDetails | Unset
        if isinstance(_details,  Unset):
            details = UNSET
        else:
            details = ErrorEnvelopeErrorErrorCauseDetails.from_dict(_details)




        _extensions = d.pop("extensions", UNSET)
        extensions: ErrorEnvelopeErrorErrorCauseExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = ErrorEnvelopeErrorErrorCauseExtensions.from_dict(_extensions)




        error_envelope_error_error_cause = cls(
            message=message,
            code=code,
            details=details,
            extensions=extensions,
        )

        return error_envelope_error_error_cause




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_profile_list_response_runtime_profile_defaults_env import RuntimeProfileListResponseRuntimeProfileDefaultsEnv





T = TypeVar("T", bound="RuntimeProfileListResponseRuntimeProfileDefaults")



@_attrs_define
class RuntimeProfileListResponseRuntimeProfileDefaults:
    """ 
        Attributes:
            args (list[str] | Unset):
            env (RuntimeProfileListResponseRuntimeProfileDefaultsEnv | Unset):
            tool_registry_url (str | Unset): Transport-agnostic locator URI for an API endpoint (e.g.
                http://127.0.0.1:43120). Future deployments may use other URI schemes (e.g. unix://...).
     """

    args: list[str] | Unset = UNSET
    env: RuntimeProfileListResponseRuntimeProfileDefaultsEnv | Unset = UNSET
    tool_registry_url: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_profile_list_response_runtime_profile_defaults_env import RuntimeProfileListResponseRuntimeProfileDefaultsEnv
        args: list[str] | Unset = UNSET
        if not isinstance(self.args, Unset):
            args = self.args



        env: dict[str, Any] | Unset = UNSET
        if not isinstance(self.env, Unset):
            env = self.env.to_dict()

        tool_registry_url = self.tool_registry_url


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if args is not UNSET:
            field_dict["args"] = args
        if env is not UNSET:
            field_dict["env"] = env
        if tool_registry_url is not UNSET:
            field_dict["tool_registry_url"] = tool_registry_url

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_profile_list_response_runtime_profile_defaults_env import RuntimeProfileListResponseRuntimeProfileDefaultsEnv
        d = dict(src_dict)
        args = cast(list[str], d.pop("args", UNSET))


        _env = d.pop("env", UNSET)
        env: RuntimeProfileListResponseRuntimeProfileDefaultsEnv | Unset
        if isinstance(_env,  Unset):
            env = UNSET
        else:
            env = RuntimeProfileListResponseRuntimeProfileDefaultsEnv.from_dict(_env)




        tool_registry_url = d.pop("tool_registry_url", UNSET)

        runtime_profile_list_response_runtime_profile_defaults = cls(
            args=args,
            env=env,
            tool_registry_url=tool_registry_url,
        )

        return runtime_profile_list_response_runtime_profile_defaults




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.tool_invocation_result_extensions import ToolInvocationResultExtensions
  from ..models.tool_invocation_result_result import ToolInvocationResultResult
  from ..models.tool_invocation_result_error import ToolInvocationResultError





T = TypeVar("T", bound="ToolInvocationResult")



@_attrs_define
class ToolInvocationResult:
    """ 
        Attributes:
            invocation_id (str):
            ok (bool):
            duration_ms (int | Unset):
            error (ToolInvocationResultError | Unset):
            extensions (ToolInvocationResultExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            result (ToolInvocationResultResult | Unset):
     """

    invocation_id: str
    ok: bool
    duration_ms: int | Unset = UNSET
    error: ToolInvocationResultError | Unset = UNSET
    extensions: ToolInvocationResultExtensions | Unset = UNSET
    result: ToolInvocationResultResult | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.tool_invocation_result_extensions import ToolInvocationResultExtensions
        from ..models.tool_invocation_result_result import ToolInvocationResultResult
        from ..models.tool_invocation_result_error import ToolInvocationResultError
        invocation_id = self.invocation_id

        ok = self.ok

        duration_ms = self.duration_ms

        error: dict[str, Any] | Unset = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        result: dict[str, Any] | Unset = UNSET
        if not isinstance(self.result, Unset):
            result = self.result.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "invocation_id": invocation_id,
            "ok": ok,
        })
        if duration_ms is not UNSET:
            field_dict["duration_ms"] = duration_ms
        if error is not UNSET:
            field_dict["error"] = error
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if result is not UNSET:
            field_dict["result"] = result

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.tool_invocation_result_extensions import ToolInvocationResultExtensions
        from ..models.tool_invocation_result_result import ToolInvocationResultResult
        from ..models.tool_invocation_result_error import ToolInvocationResultError
        d = dict(src_dict)
        invocation_id = d.pop("invocation_id")

        ok = d.pop("ok")

        duration_ms = d.pop("duration_ms", UNSET)

        _error = d.pop("error", UNSET)
        error: ToolInvocationResultError | Unset
        if isinstance(_error,  Unset):
            error = UNSET
        else:
            error = ToolInvocationResultError.from_dict(_error)




        _extensions = d.pop("extensions", UNSET)
        extensions: ToolInvocationResultExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = ToolInvocationResultExtensions.from_dict(_extensions)




        _result = d.pop("result", UNSET)
        result: ToolInvocationResultResult | Unset
        if isinstance(_result,  Unset):
            result = UNSET
        else:
            result = ToolInvocationResultResult.from_dict(_result)




        tool_invocation_result = cls(
            invocation_id=invocation_id,
            ok=ok,
            duration_ms=duration_ms,
            error=error,
            extensions=extensions,
            result=result,
        )

        return tool_invocation_result




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.version_info_extensions import VersionInfoExtensions
  from ..models.version_info_build import VersionInfoBuild





T = TypeVar("T", bound="VersionInfo")



@_attrs_define
class VersionInfo:
    """ 
        Attributes:
            service_name (str):
            service_version (str):
            supported_api_versions (list[str]):
            build (VersionInfoBuild | Unset):
            extensions (VersionInfoExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
     """

    service_name: str
    service_version: str
    supported_api_versions: list[str]
    build: VersionInfoBuild | Unset = UNSET
    extensions: VersionInfoExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.version_info_extensions import VersionInfoExtensions
        from ..models.version_info_build import VersionInfoBuild
        service_name = self.service_name

        service_version = self.service_version

        supported_api_versions = self.supported_api_versions



        build: dict[str, Any] | Unset = UNSET
        if not isinstance(self.build, Unset):
            build = self.build.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "service_name": service_name,
            "service_version": service_version,
            "supported_api_versions": supported_api_versions,
        })
        if build is not UNSET:
            field_dict["build"] = build
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.version_info_extensions import VersionInfoExtensions
        from ..models.version_info_build import VersionInfoBuild
        d = dict(src_dict)
        service_name = d.pop("service_name")

        service_version = d.pop("service_version")

        supported_api_versions = cast(list[str], d.pop("supported_api_versions"))


        _build = d.pop("build", UNSET)
        build: VersionInfoBuild | Unset
        if isinstance(_build,  Unset):
            build = UNSET
        else:
            build = VersionInfoBuild.from_dict(_build)




        _extensions = d.pop("extensions", UNSET)
        extensions: VersionInfoExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = VersionInfoExtensions.from_dict(_extensions)




        version_info = cls(
            service_name=service_name,
            service_version=service_version,
            supported_api_versions=supported_api_versions,
            build=build,
            extensions=extensions,
        )

        return version_info




""" Contains all the data models used in inputs/outputs """

from .error_envelope import ErrorEnvelope
from .error_envelope_error import ErrorEnvelopeError
from .error_envelope_error_details import ErrorEnvelopeErrorDetails
from .error_envelope_error_error_cause import ErrorEnvelopeErrorErrorCause
from .error_envelope_error_error_cause_details import ErrorEnvelopeErrorErrorCauseDetails
from .error_envelope_error_error_cause_extensions import ErrorEnvelopeErrorErrorCauseExtensions
from .error_envelope_error_extensions import ErrorEnvelopeErrorExtensions
from .error_envelope_extensions import ErrorEnvelopeExtensions
from .health import Health
from .health_checks_item import HealthChecksItem
from .health_checks_item_details import HealthChecksItemDetails
from .health_checks_item_status import HealthChecksItemStatus
from .health_extensions import HealthExtensions
from .health_status import HealthStatus
from .run_event import RunEvent
from .run_event_data import RunEventData
from .run_event_extensions import RunEventExtensions
from .run_event_type import RunEventType
from .run_request import RunRequest
from .run_request_extensions import RunRequestExtensions
from .run_request_input import RunRequestInput
from .run_request_input_context import RunRequestInputContext
from .run_request_input_data import RunRequestInputData
from .run_request_limits import RunRequestLimits
from .run_request_metadata import RunRequestMetadata
from .run_request_metadata_annotations import RunRequestMetadataAnnotations
from .run_request_metadata_extensions import RunRequestMetadataExtensions
from .run_request_metadata_labels import RunRequestMetadataLabels
from .run_request_runtime_selector import RunRequestRuntimeSelector
from .run_request_tool_policy import RunRequestToolPolicy
from .run_result import RunResult
from .run_result_error import RunResultError
from .run_result_error_details import RunResultErrorDetails
from .run_result_error_error_cause import RunResultErrorErrorCause
from .run_result_error_error_cause_details import RunResultErrorErrorCauseDetails
from .run_result_error_error_cause_extensions import RunResultErrorErrorCauseExtensions
from .run_result_error_extensions import RunResultErrorExtensions
from .run_result_extensions import RunResultExtensions
from .run_result_output import RunResultOutput
from .run_result_resource_ref import RunResultResourceRef
from .run_result_resource_ref_extensions import RunResultResourceRefExtensions
from .run_result_usage import RunResultUsage
from .run_status import RunStatus
from .run_status_extensions import RunStatusExtensions
from .run_status_state import RunStatusState
from .version_info import VersionInfo
from .version_info_build import VersionInfoBuild
from .version_info_extensions import VersionInfoExtensions

__all__ = (
    "ErrorEnvelope",
    "ErrorEnvelopeError",
    "ErrorEnvelopeErrorDetails",
    "ErrorEnvelopeErrorErrorCause",
    "ErrorEnvelopeErrorErrorCauseDetails",
    "ErrorEnvelopeErrorErrorCauseExtensions",
    "ErrorEnvelopeErrorExtensions",
    "ErrorEnvelopeExtensions",
    "Health",
    "HealthChecksItem",
    "HealthChecksItemDetails",
    "HealthChecksItemStatus",
    "HealthExtensions",
    "HealthStatus",
    "RunEvent",
    "RunEventData",
    "RunEventExtensions",
    "RunEventType",
    "RunRequest",
    "RunRequestExtensions",
    "RunRequestInput",
    "RunRequestInputContext",
    "RunRequestInputData",
    "RunRequestLimits",
    "RunRequestMetadata",
    "RunRequestMetadataAnnotations",
    "RunRequestMetadataExtensions",
    "RunRequestMetadataLabels",
    "RunRequestRuntimeSelector",
    "RunRequestToolPolicy",
    "RunResult",
    "RunResultError",
    "RunResultErrorDetails",
    "RunResultErrorErrorCause",
    "RunResultErrorErrorCauseDetails",
    "RunResultErrorErrorCauseExtensions",
    "RunResultErrorExtensions",
    "RunResultExtensions",
    "RunResultOutput",
    "RunResultResourceRef",
    "RunResultResourceRefExtensions",
    "RunResultUsage",
    "RunStatus",
    "RunStatusExtensions",
    "RunStatusState",
    "VersionInfo",
    "VersionInfoBuild",
    "VersionInfoExtensions",
)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.run_result_output import RunResultOutput
  from ..models.run_result_extensions import RunResultExtensions
  from ..models.run_result_resource_ref import RunResultResourceRef
  from ..models.run_result_error import RunResultError
  from ..models.run_result_usage import RunResultUsage





T = TypeVar("T", bound="RunResult")



@_attrs_define
class RunResult:
    """ 
        Attributes:
            ok (bool):
            run_id (str):
            artifacts (list[RunResultResourceRef] | Unset):
            error (RunResultError | Unset):
            extensions (RunResultExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            output (RunResultOutput | Unset):
            usage (RunResultUsage | Unset):
     """

    ok: bool
    run_id: str
    artifacts: list[RunResultResourceRef] | Unset = UNSET
    error: RunResultError | Unset = UNSET
    extensions: RunResultExtensions | Unset = UNSET
    output: RunResultOutput | Unset = UNSET
    usage: RunResultUsage | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_result_output import RunResultOutput
        from ..models.run_result_extensions import RunResultExtensions
        from ..models.run_result_resource_ref import RunResultResourceRef
        from ..models.run_result_error import RunResultError
        from ..models.run_result_usage import RunResultUsage
        ok = self.ok

        run_id = self.run_id

        artifacts: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.artifacts, Unset):
            artifacts = []
            for artifacts_item_data in self.artifacts:
                artifacts_item = artifacts_item_data.to_dict()
                artifacts.append(artifacts_item)



        error: dict[str, Any] | Unset = UNSET
        if not isinstance(self.error, Unset):
            error = self.error.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        output: dict[str, Any] | Unset = UNSET
        if not isinstance(self.output, Unset):
            output = self.output.to_dict()

        usage: dict[str, Any] | Unset = UNSET
        if not isinstance(self.usage, Unset):
            usage = self.usage.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "ok": ok,
            "run_id": run_id,
        })
        if artifacts is not UNSET:
            field_dict["artifacts"] = artifacts
        if error is not UNSET:
            field_dict["error"] = error
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if output is not UNSET:
            field_dict["output"] = output
        if usage is not UNSET:
            field_dict["usage"] = usage

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_result_output import RunResultOutput
        from ..models.run_result_extensions import RunResultExtensions
        from ..models.run_result_resource_ref import RunResultResourceRef
        from ..models.run_result_error import RunResultError
        from ..models.run_result_usage import RunResultUsage
        d = dict(src_dict)
        ok = d.pop("ok")

        run_id = d.pop("run_id")

        _artifacts = d.pop("artifacts", UNSET)
        artifacts: list[RunResultResourceRef] | Unset = UNSET
        if _artifacts is not UNSET:
            artifacts = []
            for artifacts_item_data in _artifacts:
                artifacts_item = RunResultResourceRef.from_dict(artifacts_item_data)



                artifacts.append(artifacts_item)


        _error = d.pop("error", UNSET)
        error: RunResultError | Unset
        if isinstance(_error,  Unset):
            error = UNSET
        else:
            error = RunResultError.from_dict(_error)




        _extensions = d.pop("extensions", UNSET)
        extensions: RunResultExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RunResultExtensions.from_dict(_extensions)




        _output = d.pop("output", UNSET)
        output: RunResultOutput | Unset
        if isinstance(_output,  Unset):
            output = UNSET
        else:
            output = RunResultOutput.from_dict(_output)




        _usage = d.pop("usage", UNSET)
        usage: RunResultUsage | Unset
        if isinstance(_usage,  Unset):
            usage = UNSET
        else:
            usage = RunResultUsage.from_dict(_usage)




        run_result = cls(
            ok=ok,
            run_id=run_id,
            artifacts=artifacts,
            error=error,
            extensions=extensions,
            output=output,
            usage=usage,
        )

        return run_result




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.health_checks_item_status import HealthChecksItemStatus
from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.health_checks_item_details import HealthChecksItemDetails





T = TypeVar("T", bound="HealthChecksItem")



@_attrs_define
class HealthChecksItem:
    """ 
        Attributes:
            name (str):
            status (HealthChecksItemStatus):
            details (HealthChecksItemDetails | Unset):
            message (str | Unset):
     """

    name: str
    status: HealthChecksItemStatus
    details: HealthChecksItemDetails | Unset = UNSET
    message: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.health_checks_item_details import HealthChecksItemDetails
        name = self.name

        status = self.status.value

        details: dict[str, Any] | Unset = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict()

        message = self.message


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "name": name,
            "status": status,
        })
        if details is not UNSET:
            field_dict["details"] = details
        if message is not UNSET:
            field_dict["message"] = message

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.health_checks_item_details import HealthChecksItemDetails
        d = dict(src_dict)
        name = d.pop("name")

        status = HealthChecksItemStatus(d.pop("status"))




        _details = d.pop("details", UNSET)
        details: HealthChecksItemDetails | Unset
        if isinstance(_details,  Unset):
            details = UNSET
        else:
            details = HealthChecksItemDetails.from_dict(_details)




        message = d.pop("message", UNSET)

        health_checks_item = cls(
            name=name,
            status=status,
            details=details,
            message=message,
        )

        return health_checks_item




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.trace_response_extensions import TraceResponseExtensions
  from ..models.trace_response_trace_event import TraceResponseTraceEvent





T = TypeVar("T", bound="TraceResponse")



@_attrs_define
class TraceResponse:
    """ 
        Attributes:
            events (list[TraceResponseTraceEvent] | Unset):
            extensions (TraceResponseExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            trace_uri (str | Unset):
     """

    events: list[TraceResponseTraceEvent] | Unset = UNSET
    extensions: TraceResponseExtensions | Unset = UNSET
    trace_uri: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.trace_response_extensions import TraceResponseExtensions
        from ..models.trace_response_trace_event import TraceResponseTraceEvent
        events: list[dict[str, Any]] | Unset = UNSET
        if not isinstance(self.events, Unset):
            events = []
            for events_item_data in self.events:
                events_item = events_item_data.to_dict()
                events.append(events_item)



        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        trace_uri = self.trace_uri


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if events is not UNSET:
            field_dict["events"] = events
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if trace_uri is not UNSET:
            field_dict["trace_uri"] = trace_uri

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.trace_response_extensions import TraceResponseExtensions
        from ..models.trace_response_trace_event import TraceResponseTraceEvent
        d = dict(src_dict)
        _events = d.pop("events", UNSET)
        events: list[TraceResponseTraceEvent] | Unset = UNSET
        if _events is not UNSET:
            events = []
            for events_item_data in _events:
                events_item = TraceResponseTraceEvent.from_dict(events_item_data)



                events.append(events_item)


        _extensions = d.pop("extensions", UNSET)
        extensions: TraceResponseExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = TraceResponseExtensions.from_dict(_extensions)




        trace_uri = d.pop("trace_uri", UNSET)

        trace_response = cls(
            events=events,
            extensions=extensions,
            trace_uri=trace_uri,
        )

        return trace_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast






T = TypeVar("T", bound="RunRequestToolPolicy")



@_attrs_define
class RunRequestToolPolicy:
    """ 
        Attributes:
            allow_tool_ids (list[str] | Unset):
            deny_tool_ids (list[str] | Unset):
     """

    allow_tool_ids: list[str] | Unset = UNSET
    deny_tool_ids: list[str] | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        allow_tool_ids: list[str] | Unset = UNSET
        if not isinstance(self.allow_tool_ids, Unset):
            allow_tool_ids = self.allow_tool_ids



        deny_tool_ids: list[str] | Unset = UNSET
        if not isinstance(self.deny_tool_ids, Unset):
            deny_tool_ids = self.deny_tool_ids




        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if allow_tool_ids is not UNSET:
            field_dict["allow_tool_ids"] = allow_tool_ids
        if deny_tool_ids is not UNSET:
            field_dict["deny_tool_ids"] = deny_tool_ids

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        allow_tool_ids = cast(list[str], d.pop("allow_tool_ids", UNSET))


        deny_tool_ids = cast(list[str], d.pop("deny_tool_ids", UNSET))


        run_request_tool_policy = cls(
            allow_tool_ids=allow_tool_ids,
            deny_tool_ids=deny_tool_ids,
        )

        return run_request_tool_policy




from enum import Enum

class RunEventType(str, Enum):
    ERROR = "error"
    FINAL = "final"
    STEP = "step"
    TOKEN = "token"
    TOOL_CALL = "tool_call"
    TOOL_RESULT = "tool_result"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from dateutil.parser import isoparse
from typing import cast
import datetime






T = TypeVar("T", bound="VersionInfoBuild")



@_attrs_define
class VersionInfoBuild:
    """ 
        Attributes:
            built_at (datetime.datetime | Unset):
            commit (str | Unset):
            dirty (bool | Unset):
     """

    built_at: datetime.datetime | Unset = UNSET
    commit: str | Unset = UNSET
    dirty: bool | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        built_at: str | Unset = UNSET
        if not isinstance(self.built_at, Unset):
            built_at = self.built_at.isoformat()

        commit = self.commit

        dirty = self.dirty


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if built_at is not UNSET:
            field_dict["built_at"] = built_at
        if commit is not UNSET:
            field_dict["commit"] = commit
        if dirty is not UNSET:
            field_dict["dirty"] = dirty

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        _built_at = d.pop("built_at", UNSET)
        built_at: datetime.datetime | Unset
        if isinstance(_built_at,  Unset):
            built_at = UNSET
        else:
            built_at = isoparse(_built_at)




        commit = d.pop("commit", UNSET)

        dirty = d.pop("dirty", UNSET)

        version_info_build = cls(
            built_at=built_at,
            commit=commit,
            dirty=dirty,
        )

        return version_info_build




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.error_envelope_error import ErrorEnvelopeError
  from ..models.error_envelope_extensions import ErrorEnvelopeExtensions





T = TypeVar("T", bound="ErrorEnvelope")



@_attrs_define
class ErrorEnvelope:
    """ 
        Attributes:
            error (ErrorEnvelopeError):
            extensions (ErrorEnvelopeExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
     """

    error: ErrorEnvelopeError
    extensions: ErrorEnvelopeExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.error_envelope_error import ErrorEnvelopeError
        from ..models.error_envelope_extensions import ErrorEnvelopeExtensions
        error = self.error.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "error": error,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.error_envelope_error import ErrorEnvelopeError
        from ..models.error_envelope_extensions import ErrorEnvelopeExtensions
        d = dict(src_dict)
        error = ErrorEnvelopeError.from_dict(d.pop("error"))




        _extensions = d.pop("extensions", UNSET)
        extensions: ErrorEnvelopeExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = ErrorEnvelopeExtensions.from_dict(_extensions)




        error_envelope = cls(
            error=error,
            extensions=extensions,
        )

        return error_envelope




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.tool_invocation_result_error_extensions import ToolInvocationResultErrorExtensions
  from ..models.tool_invocation_result_error_details import ToolInvocationResultErrorDetails
  from ..models.tool_invocation_result_error_error_cause import ToolInvocationResultErrorErrorCause





T = TypeVar("T", bound="ToolInvocationResultError")



@_attrs_define
class ToolInvocationResultError:
    """ 
        Attributes:
            code (str):
            message (str):
            cause (ToolInvocationResultErrorErrorCause | Unset):
            details (ToolInvocationResultErrorDetails | Unset):
            extensions (ToolInvocationResultErrorExtensions | Unset): Optional vendor extension map. Keys must be namespaced
                as <reverse_dns_or_org>.<key>.
            retryable (bool | Unset):
     """

    code: str
    message: str
    cause: ToolInvocationResultErrorErrorCause | Unset = UNSET
    details: ToolInvocationResultErrorDetails | Unset = UNSET
    extensions: ToolInvocationResultErrorExtensions | Unset = UNSET
    retryable: bool | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.tool_invocation_result_error_extensions import ToolInvocationResultErrorExtensions
        from ..models.tool_invocation_result_error_details import ToolInvocationResultErrorDetails
        from ..models.tool_invocation_result_error_error_cause import ToolInvocationResultErrorErrorCause
        code = self.code

        message = self.message

        cause: dict[str, Any] | Unset = UNSET
        if not isinstance(self.cause, Unset):
            cause = self.cause.to_dict()

        details: dict[str, Any] | Unset = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        retryable = self.retryable


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "code": code,
            "message": message,
        })
        if cause is not UNSET:
            field_dict["cause"] = cause
        if details is not UNSET:
            field_dict["details"] = details
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if retryable is not UNSET:
            field_dict["retryable"] = retryable

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.tool_invocation_result_error_extensions import ToolInvocationResultErrorExtensions
        from ..models.tool_invocation_result_error_details import ToolInvocationResultErrorDetails
        from ..models.tool_invocation_result_error_error_cause import ToolInvocationResultErrorErrorCause
        d = dict(src_dict)
        code = d.pop("code")

        message = d.pop("message")

        _cause = d.pop("cause", UNSET)
        cause: ToolInvocationResultErrorErrorCause | Unset
        if isinstance(_cause,  Unset):
            cause = UNSET
        else:
            cause = ToolInvocationResultErrorErrorCause.from_dict(_cause)




        _details = d.pop("details", UNSET)
        details: ToolInvocationResultErrorDetails | Unset
        if isinstance(_details,  Unset):
            details = UNSET
        else:
            details = ToolInvocationResultErrorDetails.from_dict(_details)




        _extensions = d.pop("extensions", UNSET)
        extensions: ToolInvocationResultErrorExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = ToolInvocationResultErrorExtensions.from_dict(_extensions)




        retryable = d.pop("retryable", UNSET)

        tool_invocation_result_error = cls(
            code=code,
            message=message,
            cause=cause,
            details=details,
            extensions=extensions,
            retryable=retryable,
        )

        return tool_invocation_result_error




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_profile_defaults import RuntimeProfileDefaults
  from ..models.runtime_profile_metadata import RuntimeProfileMetadata
  from ..models.runtime_profile_extensions import RuntimeProfileExtensions





T = TypeVar("T", bound="RuntimeProfile")



@_attrs_define
class RuntimeProfile:
    """ 
        Attributes:
            runtime_profile (str):
            defaults (RuntimeProfileDefaults | Unset):
            description (str | Unset):
            extensions (RuntimeProfileExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            metadata (RuntimeProfileMetadata | Unset):
            runtime_name (str | Unset):
     """

    runtime_profile: str
    defaults: RuntimeProfileDefaults | Unset = UNSET
    description: str | Unset = UNSET
    extensions: RuntimeProfileExtensions | Unset = UNSET
    metadata: RuntimeProfileMetadata | Unset = UNSET
    runtime_name: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_profile_defaults import RuntimeProfileDefaults
        from ..models.runtime_profile_metadata import RuntimeProfileMetadata
        from ..models.runtime_profile_extensions import RuntimeProfileExtensions
        runtime_profile = self.runtime_profile

        defaults: dict[str, Any] | Unset = UNSET
        if not isinstance(self.defaults, Unset):
            defaults = self.defaults.to_dict()

        description = self.description

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        runtime_name = self.runtime_name


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "runtime_profile": runtime_profile,
        })
        if defaults is not UNSET:
            field_dict["defaults"] = defaults
        if description is not UNSET:
            field_dict["description"] = description
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if runtime_name is not UNSET:
            field_dict["runtime_name"] = runtime_name

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_profile_defaults import RuntimeProfileDefaults
        from ..models.runtime_profile_metadata import RuntimeProfileMetadata
        from ..models.runtime_profile_extensions import RuntimeProfileExtensions
        d = dict(src_dict)
        runtime_profile = d.pop("runtime_profile")

        _defaults = d.pop("defaults", UNSET)
        defaults: RuntimeProfileDefaults | Unset
        if isinstance(_defaults,  Unset):
            defaults = UNSET
        else:
            defaults = RuntimeProfileDefaults.from_dict(_defaults)




        description = d.pop("description", UNSET)

        _extensions = d.pop("extensions", UNSET)
        extensions: RuntimeProfileExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RuntimeProfileExtensions.from_dict(_extensions)




        _metadata = d.pop("metadata", UNSET)
        metadata: RuntimeProfileMetadata | Unset
        if isinstance(_metadata,  Unset):
            metadata = UNSET
        else:
            metadata = RuntimeProfileMetadata.from_dict(_metadata)




        runtime_name = d.pop("runtime_name", UNSET)

        runtime_profile = cls(
            runtime_profile=runtime_profile,
            defaults=defaults,
            description=description,
            extensions=extensions,
            metadata=metadata,
            runtime_name=runtime_name,
        )

        return runtime_profile




"""ARP Daemon API facade (preferred) + low-level client package."""

from __future__ import annotations

from importlib import import_module
from typing import TYPE_CHECKING, Any

__all__ = [
    'ArpApiError',
    'CreateInstancesRequest',
    'DaemonClient',
    'DeleteInstanceRequest',
    'DeleteRuntimeProfileRequest',
    'GetRunResultRequest',
    'GetRunStatusRequest',
    'GetRunTraceRequest',
    'Health',
    'HealthRequest',
    'InstanceCreateRequest',
    'InstanceCreateResponse',
    'InstanceListResponse',
    'InstanceRegisterRequest',
    'InstanceRegisterResponse',
    'ListInstancesRequest',
    'ListRunsRequest',
    'ListRuntimeProfilesRequest',
    'RegisterInstanceRequest',
    'RunListResponse',
    'RunRequest',
    'RunResult',
    'RunStatus',
    'RuntimeProfile',
    'RuntimeProfileListResponse',
    'RuntimeProfileUpsertRequest',
    'SubmitRunRequest',
    'TraceResponse',
    'UpsertRuntimeProfileRequest',
    'VersionInfo',
    'VersionRequest',
]

_EXPORT_MAP: dict[str, str] = {
    'CreateInstancesRequest': '.sdk',
    'DaemonClient': '.sdk',
    'DeleteInstanceRequest': '.sdk',
    'DeleteRuntimeProfileRequest': '.sdk',
    'GetRunResultRequest': '.sdk',
    'GetRunStatusRequest': '.sdk',
    'GetRunTraceRequest': '.sdk',
    'Health': '.models',
    'HealthRequest': '.sdk',
    'InstanceCreateRequest': '.models',
    'InstanceCreateResponse': '.models',
    'InstanceListResponse': '.models',
    'InstanceRegisterRequest': '.models',
    'InstanceRegisterResponse': '.models',
    'ListInstancesRequest': '.sdk',
    'ListRunsRequest': '.sdk',
    'ListRuntimeProfilesRequest': '.sdk',
    'RegisterInstanceRequest': '.sdk',
    'RunListResponse': '.models',
    'RunRequest': 'arp_sdk.runtime.models',
    'RunResult': 'arp_sdk.runtime.models',
    'RunStatus': 'arp_sdk.runtime.models',
    'RuntimeProfile': '.models',
    'RuntimeProfileListResponse': '.models',
    'RuntimeProfileUpsertRequest': '.models',
    'SubmitRunRequest': '.sdk',
    'TraceResponse': '.models',
    'UpsertRuntimeProfileRequest': '.sdk',
    'VersionInfo': '.models',
    'VersionRequest': '.sdk',
}

if TYPE_CHECKING:
    from arp_sdk.errors import ArpApiError
    from .sdk import CreateInstancesRequest, DaemonClient, DeleteInstanceRequest, DeleteRuntimeProfileRequest, GetRunResultRequest, GetRunStatusRequest, GetRunTraceRequest, HealthRequest, ListInstancesRequest, ListRunsRequest, ListRuntimeProfilesRequest, RegisterInstanceRequest, SubmitRunRequest, UpsertRuntimeProfileRequest, VersionRequest
    from .models import Health, InstanceCreateRequest, InstanceCreateResponse, InstanceListResponse, InstanceRegisterRequest, InstanceRegisterResponse, RunListResponse, RuntimeProfile, RuntimeProfileListResponse, RuntimeProfileUpsertRequest, TraceResponse, VersionInfo
    from arp_sdk.runtime.models import RunRequest, RunResult, RunStatus

def __getattr__(name: str) -> Any:
    if name == "ArpApiError":
        from arp_sdk.errors import ArpApiError as _ArpApiError

        return _ArpApiError
    module = _EXPORT_MAP.get(name)
    if module is None:
        raise AttributeError(name)
    if module.startswith("."):
        return getattr(import_module(module, __name__), name)
    return getattr(import_module(module), name)




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.run_event_type import RunEventType
from ..types import UNSET, Unset
from dateutil.parser import isoparse
from typing import cast
import datetime

if TYPE_CHECKING:
  from ..models.run_event_data import RunEventData
  from ..models.run_event_extensions import RunEventExtensions





T = TypeVar("T", bound="RunEvent")



@_attrs_define
class RunEvent:
    """ 
        Attributes:
            run_id (str):
            seq (int):
            time (datetime.datetime):
            type_ (RunEventType):
            data (RunEventData | Unset):
            extensions (RunEventExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
     """

    run_id: str
    seq: int
    time: datetime.datetime
    type_: RunEventType
    data: RunEventData | Unset = UNSET
    extensions: RunEventExtensions | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_event_data import RunEventData
        from ..models.run_event_extensions import RunEventExtensions
        run_id = self.run_id

        seq = self.seq

        time = self.time.isoformat()

        type_ = self.type_.value

        data: dict[str, Any] | Unset = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "run_id": run_id,
            "seq": seq,
            "time": time,
            "type": type_,
        })
        if data is not UNSET:
            field_dict["data"] = data
        if extensions is not UNSET:
            field_dict["extensions"] = extensions

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_event_data import RunEventData
        from ..models.run_event_extensions import RunEventExtensions
        d = dict(src_dict)
        run_id = d.pop("run_id")

        seq = d.pop("seq")

        time = isoparse(d.pop("time"))




        type_ = RunEventType(d.pop("type"))




        _data = d.pop("data", UNSET)
        data: RunEventData | Unset
        if isinstance(_data,  Unset):
            data = UNSET
        else:
            data = RunEventData.from_dict(_data)




        _extensions = d.pop("extensions", UNSET)
        extensions: RunEventExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RunEventExtensions.from_dict(_extensions)




        run_event = cls(
            run_id=run_id,
            seq=seq,
            time=time,
            type_=type_,
            data=data,
            extensions=extensions,
        )

        return run_event




from __future__ import annotations

from dataclasses import dataclass
from typing import Any, TypeVar, overload

import httpx

from arp_sdk.errors import ArpApiError
from arp_sdk.models import (
    InstanceCreateRequest,
    InstanceCreateResponse,
    InstanceListResponse,
    InstanceRegisterRequest,
    InstanceRegisterResponse,
    RunListResponse,
    RunRequest,
    RunResult,
    RunStatus,
    RuntimeProfile,
    RuntimeProfileListResponse,
    RuntimeProfileUpsertRequest,
    TraceResponse,
)

from .api.health import (
    health,
)

from .api.instances import (
    create_instances,
    delete_instance,
    list_instances,
    register_instance,
)

from .api.runs import (
    get_run_result,
    get_run_status,
    get_run_trace,
    list_runs,
    submit_run,
)

from .api.runtime_profiles import (
    delete_runtime_profile,
    list_runtime_profiles,
    upsert_runtime_profile,
)

from .api.version import (
    version,
)

from .client import Client as _LowLevelClient
from .models import ErrorEnvelope as _ErrorEnvelope
from .models import Health, VersionInfo
from .models import (
    RunRequest as _RunRequest,
)
from .types import Response as _Response
from .types import Unset as _Unset
from .types import UNSET as _UNSET

T = TypeVar("T")

def _coerce_model(value: Any, target: type[T]) -> T:
    if isinstance(value, target):
        return value
    if hasattr(value, "to_dict") and hasattr(target, "from_dict"):
        return target.from_dict(value.to_dict())  # type: ignore[attr-defined]
    if isinstance(value, dict) and hasattr(target, "from_dict"):
        return target.from_dict(value)  # type: ignore[attr-defined]
    raise TypeError(f"Cannot coerce {type(value)} to {target}")

def _raise_for_error_envelope(*, envelope: _ErrorEnvelope, status_code: int | None, raw: Any | None) -> None:
    details: Any | None = None
    if not isinstance(envelope.error.details, _Unset):
        details = envelope.error.details.to_dict()
    raise ArpApiError(
        code=str(envelope.error.code),
        message=str(envelope.error.message),
        details=details,
        status_code=status_code,
        raw=raw,
    )

def _unwrap(response: _Response[Any], *, allow_none: bool = False) -> Any:
    parsed = response.parsed
    if parsed is None:
        if allow_none:
            return None
        raise ArpApiError(
            code="unexpected_empty_response",
            message="API returned an empty response",
            status_code=int(response.status_code),
            raw=response.content,
        )
    if isinstance(parsed, _ErrorEnvelope):
        _raise_for_error_envelope(envelope=parsed, status_code=int(response.status_code), raw=parsed.to_dict())
    return parsed

@dataclass(slots=True)
class CreateInstancesRequest:
    body: InstanceCreateRequest

@dataclass(slots=True)
class DeleteInstanceRequest:
    instance_id: str

@dataclass(slots=True)
class DeleteRuntimeProfileRequest:
    runtime_profile: str

@dataclass(slots=True)
class GetRunResultRequest:
    run_id: str

@dataclass(slots=True)
class GetRunStatusRequest:
    run_id: str

@dataclass(slots=True)
class GetRunTraceRequest:
    run_id: str

@dataclass(slots=True)
class HealthRequest:
    pass

@dataclass(slots=True)
class ListInstancesRequest:
    pass

@dataclass(slots=True)
class ListRunsRequest:
    page_size: int | None = None
    page_token: str | None = None

@dataclass(slots=True)
class ListRuntimeProfilesRequest:
    pass

@dataclass(slots=True)
class RegisterInstanceRequest:
    body: InstanceRegisterRequest

@dataclass(slots=True)
class SubmitRunRequest:
    body: RunRequest

@dataclass(slots=True)
class UpsertRuntimeProfileRequest:
    runtime_profile: str
    body: RuntimeProfileUpsertRequest

@dataclass(slots=True)
class VersionRequest:
    pass

class DaemonClient:
    def __init__(
        self,
        base_url: str | None = None,
        *,
        client: _LowLevelClient | None = None,
        timeout: httpx.Timeout | None = None,
        headers: dict[str, str] | None = None,
        cookies: dict[str, str] | None = None,
        verify_ssl: Any = True,
        follow_redirects: bool = False,
        raise_on_unexpected_status: bool = False,
        httpx_args: dict[str, Any] | None = None,
    ) -> None:
        if client is None:
            if base_url is None:
                raise ValueError("base_url is required when client is not provided")
            client = _LowLevelClient(
                base_url=base_url,
                timeout=timeout,
                headers={} if headers is None else dict(headers),
                cookies={} if cookies is None else dict(cookies),
                verify_ssl=verify_ssl,
                follow_redirects=follow_redirects,
                raise_on_unexpected_status=raise_on_unexpected_status,
                httpx_args={} if httpx_args is None else dict(httpx_args),
            )
        self._client = client

    @property
    def raw_client(self) -> _LowLevelClient:
        return self._client

    @overload
    def create_instances(self, body: InstanceCreateRequest) -> InstanceCreateResponse: ...

    @overload
    def create_instances(self, body: CreateInstancesRequest) -> InstanceCreateResponse: ...

    def create_instances(self, body: CreateInstancesRequest | InstanceCreateRequest) -> InstanceCreateResponse:
        payload = body.body if isinstance(body, CreateInstancesRequest) else body
        resp = create_instances.sync_detailed(client=self._client, body=payload)
        result = _unwrap(resp)
        return result

    @overload
    def delete_instance(self, instance_id: str) -> None: ...

    @overload
    def delete_instance(self, instance_id: DeleteInstanceRequest) -> None: ...

    def delete_instance(self, instance_id: DeleteInstanceRequest | str) -> None:
        value = instance_id.instance_id if isinstance(instance_id, DeleteInstanceRequest) else instance_id
        instance_id = value
        resp = delete_instance.sync_detailed(client=self._client, instance_id=instance_id)
        _unwrap(resp, allow_none=True)
        return None

    @overload
    def delete_runtime_profile(self, runtime_profile: str) -> None: ...

    @overload
    def delete_runtime_profile(self, runtime_profile: DeleteRuntimeProfileRequest) -> None: ...

    def delete_runtime_profile(self, runtime_profile: DeleteRuntimeProfileRequest | str) -> None:
        value = runtime_profile.runtime_profile if isinstance(runtime_profile, DeleteRuntimeProfileRequest) else runtime_profile
        runtime_profile = value
        resp = delete_runtime_profile.sync_detailed(client=self._client, runtime_profile=runtime_profile)
        _unwrap(resp, allow_none=True)
        return None

    @overload
    def get_run_result(self, run_id: str) -> RunResult: ...

    @overload
    def get_run_result(self, run_id: GetRunResultRequest) -> RunResult: ...

    def get_run_result(self, run_id: GetRunResultRequest | str) -> RunResult:
        value = run_id.run_id if isinstance(run_id, GetRunResultRequest) else run_id
        run_id = value
        resp = get_run_result.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return _coerce_model(result, RunResult)

    @overload
    def get_run_status(self, run_id: str) -> RunStatus: ...

    @overload
    def get_run_status(self, run_id: GetRunStatusRequest) -> RunStatus: ...

    def get_run_status(self, run_id: GetRunStatusRequest | str) -> RunStatus:
        value = run_id.run_id if isinstance(run_id, GetRunStatusRequest) else run_id
        run_id = value
        resp = get_run_status.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return _coerce_model(result, RunStatus)

    @overload
    def get_run_trace(self, run_id: str) -> TraceResponse: ...

    @overload
    def get_run_trace(self, run_id: GetRunTraceRequest) -> TraceResponse: ...

    def get_run_trace(self, run_id: GetRunTraceRequest | str) -> TraceResponse:
        value = run_id.run_id if isinstance(run_id, GetRunTraceRequest) else run_id
        run_id = value
        resp = get_run_trace.sync_detailed(client=self._client, run_id=run_id)
        result = _unwrap(resp)
        return result

    @overload
    def health(self) -> Health: ...

    @overload
    def health(self, request: HealthRequest) -> Health: ...

    def health(self, request: HealthRequest | None = None) -> Health:
        _ = request
        resp = health.sync_detailed(client=self._client)
        return _unwrap(resp)

    @overload
    def list_instances(self) -> InstanceListResponse: ...

    @overload
    def list_instances(self, request: ListInstancesRequest) -> InstanceListResponse: ...

    def list_instances(self, request: ListInstancesRequest | None = None) -> InstanceListResponse:
        _ = request
        resp = list_instances.sync_detailed(client=self._client)
        return _unwrap(resp)

    @overload
    def list_runs(self) -> RunListResponse: ...

    @overload
    def list_runs(self, request: ListRunsRequest) -> RunListResponse: ...

    @overload
    def list_runs(self, *, page_size: int | None = None, page_token: str | None = None) -> RunListResponse: ...

    def list_runs(self, request: ListRunsRequest | None = None, *, page_size: int | None = None, page_token: str | None = None) -> RunListResponse:
        if request is not None:
            page_size = request.page_size
            page_token = request.page_token
        resp = list_runs.sync_detailed(client=self._client, page_size=_UNSET if page_size is None else page_size, page_token=_UNSET if page_token is None else page_token)
        return _unwrap(resp)

    @overload
    def list_runtime_profiles(self) -> RuntimeProfileListResponse: ...

    @overload
    def list_runtime_profiles(self, request: ListRuntimeProfilesRequest) -> RuntimeProfileListResponse: ...

    def list_runtime_profiles(self, request: ListRuntimeProfilesRequest | None = None) -> RuntimeProfileListResponse:
        _ = request
        resp = list_runtime_profiles.sync_detailed(client=self._client)
        return _unwrap(resp)

    @overload
    def register_instance(self, body: InstanceRegisterRequest) -> InstanceRegisterResponse: ...

    @overload
    def register_instance(self, body: RegisterInstanceRequest) -> InstanceRegisterResponse: ...

    def register_instance(self, body: RegisterInstanceRequest | InstanceRegisterRequest) -> InstanceRegisterResponse:
        payload = body.body if isinstance(body, RegisterInstanceRequest) else body
        resp = register_instance.sync_detailed(client=self._client, body=payload)
        result = _unwrap(resp)
        return result

    @overload
    def submit_run(self, body: RunRequest) -> RunStatus: ...

    @overload
    def submit_run(self, body: SubmitRunRequest) -> RunStatus: ...

    def submit_run(self, body: SubmitRunRequest | RunRequest) -> RunStatus:
        payload = body.body if isinstance(body, SubmitRunRequest) else body
        payload = _coerce_model(payload, _RunRequest)
        resp = submit_run.sync_detailed(client=self._client, body=payload)
        result = _unwrap(resp)
        return _coerce_model(result, RunStatus)

    def upsert_runtime_profile(self, request: UpsertRuntimeProfileRequest) -> RuntimeProfile:
        resp = upsert_runtime_profile.sync_detailed(client=self._client, runtime_profile=request.runtime_profile, body=request.body)
        result = _unwrap(resp)
        return result

    @overload
    def version(self) -> VersionInfo: ...

    @overload
    def version(self, request: VersionRequest) -> VersionInfo: ...

    def version(self, request: VersionRequest | None = None) -> VersionInfo:
        _ = request
        resp = version.sync_detailed(client=self._client)
        return _unwrap(resp)

__all__ = [
    'DaemonClient',
    'CreateInstancesRequest',
    'DeleteInstanceRequest',
    'DeleteRuntimeProfileRequest',
    'GetRunResultRequest',
    'GetRunStatusRequest',
    'GetRunTraceRequest',
    'HealthRequest',
    'ListInstancesRequest',
    'ListRunsRequest',
    'ListRuntimeProfilesRequest',
    'RegisterInstanceRequest',
    'SubmitRunRequest',
    'UpsertRuntimeProfileRequest',
    'VersionRequest',
]



from __future__ import annotations

__all__ = [
    "__version__",
    "clients", # pyright: ignore[reportUnsupportedDunderAll]
    "daemon", # pyright: ignore[reportUnsupportedDunderAll]
    "errors", # pyright: ignore[reportUnsupportedDunderAll]
    "models", # pyright: ignore[reportUnsupportedDunderAll]
    "runtime", # pyright: ignore[reportUnsupportedDunderAll]
    "tool_registry", # pyright: ignore[reportUnsupportedDunderAll]
]

__version__ = "0.1.0"

from .errors import ArpApiError  # noqa: E402

__all__.append("ArpApiError")



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.run_request_tool_policy import RunRequestToolPolicy
  from ..models.run_request_limits import RunRequestLimits
  from ..models.run_request_metadata import RunRequestMetadata
  from ..models.run_request_input import RunRequestInput
  from ..models.run_request_extensions import RunRequestExtensions
  from ..models.run_request_runtime_selector import RunRequestRuntimeSelector





T = TypeVar("T", bound="RunRequest")



@_attrs_define
class RunRequest:
    """ 
        Attributes:
            input_ (RunRequestInput):
            extensions (RunRequestExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            limits (RunRequestLimits | Unset):
            metadata (RunRequestMetadata | Unset):
            run_id (str | Unset):
            runtime_selector (RunRequestRuntimeSelector | Unset):
            tool_policy (RunRequestToolPolicy | Unset):
     """

    input_: RunRequestInput
    extensions: RunRequestExtensions | Unset = UNSET
    limits: RunRequestLimits | Unset = UNSET
    metadata: RunRequestMetadata | Unset = UNSET
    run_id: str | Unset = UNSET
    runtime_selector: RunRequestRuntimeSelector | Unset = UNSET
    tool_policy: RunRequestToolPolicy | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_request_tool_policy import RunRequestToolPolicy
        from ..models.run_request_limits import RunRequestLimits
        from ..models.run_request_metadata import RunRequestMetadata
        from ..models.run_request_input import RunRequestInput
        from ..models.run_request_extensions import RunRequestExtensions
        from ..models.run_request_runtime_selector import RunRequestRuntimeSelector
        input_ = self.input_.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        limits: dict[str, Any] | Unset = UNSET
        if not isinstance(self.limits, Unset):
            limits = self.limits.to_dict()

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        run_id = self.run_id

        runtime_selector: dict[str, Any] | Unset = UNSET
        if not isinstance(self.runtime_selector, Unset):
            runtime_selector = self.runtime_selector.to_dict()

        tool_policy: dict[str, Any] | Unset = UNSET
        if not isinstance(self.tool_policy, Unset):
            tool_policy = self.tool_policy.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "input": input_,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if limits is not UNSET:
            field_dict["limits"] = limits
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if run_id is not UNSET:
            field_dict["run_id"] = run_id
        if runtime_selector is not UNSET:
            field_dict["runtime_selector"] = runtime_selector
        if tool_policy is not UNSET:
            field_dict["tool_policy"] = tool_policy

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_request_tool_policy import RunRequestToolPolicy
        from ..models.run_request_limits import RunRequestLimits
        from ..models.run_request_metadata import RunRequestMetadata
        from ..models.run_request_input import RunRequestInput
        from ..models.run_request_extensions import RunRequestExtensions
        from ..models.run_request_runtime_selector import RunRequestRuntimeSelector
        d = dict(src_dict)
        input_ = RunRequestInput.from_dict(d.pop("input"))




        _extensions = d.pop("extensions", UNSET)
        extensions: RunRequestExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RunRequestExtensions.from_dict(_extensions)




        _limits = d.pop("limits", UNSET)
        limits: RunRequestLimits | Unset
        if isinstance(_limits,  Unset):
            limits = UNSET
        else:
            limits = RunRequestLimits.from_dict(_limits)




        _metadata = d.pop("metadata", UNSET)
        metadata: RunRequestMetadata | Unset
        if isinstance(_metadata,  Unset):
            metadata = UNSET
        else:
            metadata = RunRequestMetadata.from_dict(_metadata)




        run_id = d.pop("run_id", UNSET)

        _runtime_selector = d.pop("runtime_selector", UNSET)
        runtime_selector: RunRequestRuntimeSelector | Unset
        if isinstance(_runtime_selector,  Unset):
            runtime_selector = UNSET
        else:
            runtime_selector = RunRequestRuntimeSelector.from_dict(_runtime_selector)




        _tool_policy = d.pop("tool_policy", UNSET)
        tool_policy: RunRequestToolPolicy | Unset
        if isinstance(_tool_policy,  Unset):
            tool_policy = UNSET
        else:
            tool_policy = RunRequestToolPolicy.from_dict(_tool_policy)




        run_request = cls(
            input_=input_,
            extensions=extensions,
            limits=limits,
            metadata=metadata,
            run_id=run_id,
            runtime_selector=runtime_selector,
            tool_policy=tool_policy,
        )

        return run_request




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_profile_upsert_request_metadata import RuntimeProfileUpsertRequestMetadata
  from ..models.runtime_profile_upsert_request_extensions import RuntimeProfileUpsertRequestExtensions
  from ..models.runtime_profile_upsert_request_defaults import RuntimeProfileUpsertRequestDefaults





T = TypeVar("T", bound="RuntimeProfileUpsertRequest")



@_attrs_define
class RuntimeProfileUpsertRequest:
    """ 
        Attributes:
            defaults (RuntimeProfileUpsertRequestDefaults | Unset):
            description (str | Unset):
            extensions (RuntimeProfileUpsertRequestExtensions | Unset): Optional vendor extension map. Keys must be
                namespaced as <reverse_dns_or_org>.<key>.
            metadata (RuntimeProfileUpsertRequestMetadata | Unset):
            runtime_name (str | Unset):
     """

    defaults: RuntimeProfileUpsertRequestDefaults | Unset = UNSET
    description: str | Unset = UNSET
    extensions: RuntimeProfileUpsertRequestExtensions | Unset = UNSET
    metadata: RuntimeProfileUpsertRequestMetadata | Unset = UNSET
    runtime_name: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_profile_upsert_request_metadata import RuntimeProfileUpsertRequestMetadata
        from ..models.runtime_profile_upsert_request_extensions import RuntimeProfileUpsertRequestExtensions
        from ..models.runtime_profile_upsert_request_defaults import RuntimeProfileUpsertRequestDefaults
        defaults: dict[str, Any] | Unset = UNSET
        if not isinstance(self.defaults, Unset):
            defaults = self.defaults.to_dict()

        description = self.description

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        runtime_name = self.runtime_name


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if defaults is not UNSET:
            field_dict["defaults"] = defaults
        if description is not UNSET:
            field_dict["description"] = description
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if runtime_name is not UNSET:
            field_dict["runtime_name"] = runtime_name

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_profile_upsert_request_metadata import RuntimeProfileUpsertRequestMetadata
        from ..models.runtime_profile_upsert_request_extensions import RuntimeProfileUpsertRequestExtensions
        from ..models.runtime_profile_upsert_request_defaults import RuntimeProfileUpsertRequestDefaults
        d = dict(src_dict)
        _defaults = d.pop("defaults", UNSET)
        defaults: RuntimeProfileUpsertRequestDefaults | Unset
        if isinstance(_defaults,  Unset):
            defaults = UNSET
        else:
            defaults = RuntimeProfileUpsertRequestDefaults.from_dict(_defaults)




        description = d.pop("description", UNSET)

        _extensions = d.pop("extensions", UNSET)
        extensions: RuntimeProfileUpsertRequestExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RuntimeProfileUpsertRequestExtensions.from_dict(_extensions)




        _metadata = d.pop("metadata", UNSET)
        metadata: RuntimeProfileUpsertRequestMetadata | Unset
        if isinstance(_metadata,  Unset):
            metadata = UNSET
        else:
            metadata = RuntimeProfileUpsertRequestMetadata.from_dict(_metadata)




        runtime_name = d.pop("runtime_name", UNSET)

        runtime_profile_upsert_request = cls(
            defaults=defaults,
            description=description,
            extensions=extensions,
            metadata=metadata,
            runtime_name=runtime_name,
        )

        return runtime_profile_upsert_request




from __future__ import annotations

from dataclasses import dataclass
from typing import Any, TypeVar, overload

import httpx

from arp_sdk.errors import ArpApiError
from arp_sdk.models import (
    ToolDefinition,
    ToolInvocationResult,
)

from .api.health import (
    health,
)

from .api.invocations import (
    invoke_tool,
)

from .api.tools import (
    get_tool,
    list_tools,
)

from .api.version import (
    version,
)

from .client import Client as _LowLevelClient
from .models import ErrorEnvelope as _ErrorEnvelope
from .models import Health, VersionInfo
from .types import Response as _Response
from .types import Unset as _Unset

T = TypeVar("T")

def _coerce_model(value: Any, target: type[T]) -> T:
    if isinstance(value, target):
        return value
    if hasattr(value, "to_dict") and hasattr(target, "from_dict"):
        return target.from_dict(value.to_dict())  # type: ignore[attr-defined]
    if isinstance(value, dict) and hasattr(target, "from_dict"):
        return target.from_dict(value)  # type: ignore[attr-defined]
    raise TypeError(f"Cannot coerce {type(value)} to {target}")

def _raise_for_error_envelope(*, envelope: _ErrorEnvelope, status_code: int | None, raw: Any | None) -> None:
    details: Any | None = None
    if not isinstance(envelope.error.details, _Unset):
        details = envelope.error.details.to_dict()
    raise ArpApiError(
        code=str(envelope.error.code),
        message=str(envelope.error.message),
        details=details,
        status_code=status_code,
        raw=raw,
    )

def _unwrap(response: _Response[Any], *, allow_none: bool = False) -> Any:
    parsed = response.parsed
    if parsed is None:
        if allow_none:
            return None
        raise ArpApiError(
            code="unexpected_empty_response",
            message="API returned an empty response",
            status_code=int(response.status_code),
            raw=response.content,
        )
    if isinstance(parsed, _ErrorEnvelope):
        _raise_for_error_envelope(envelope=parsed, status_code=int(response.status_code), raw=parsed.to_dict())
    return parsed

@dataclass(slots=True)
class GetToolRequest:
    tool_id: str

@dataclass(slots=True)
class HealthRequest:
    pass

@dataclass(slots=True)
class InvokeToolRequest:
    invocation_id: str
    args: dict[str, Any]
    tool_id: str | None = None
    tool_name: str | None = None
    context: dict[str, Any] | None = None
    caller: dict[str, Any] | None = None
    extensions: dict[str, Any] | None = None

    def __post_init__(self) -> None:
        satisfied = False
        if self.tool_id is not None:
            satisfied = True
        if self.tool_name is not None:
            satisfied = True
        if not satisfied:
            raise ValueError("InvokeToolRequest does not satisfy request constraints")

    def to_body(self) -> dict[str, Any]:
        body: dict[str, Any] = {}
        if self.invocation_id is not None:
            body['invocation_id'] = self.invocation_id
        if self.tool_id is not None:
            body['tool_id'] = self.tool_id
        if self.tool_name is not None:
            body['tool_name'] = self.tool_name
        if self.args is not None:
            body['args'] = self.args
        if self.context is not None:
            body['context'] = self.context
        if self.caller is not None:
            body['caller'] = self.caller
        if self.extensions is not None:
            body['extensions'] = self.extensions
        return body

@dataclass(slots=True)
class ListToolsRequest:
    pass

@dataclass(slots=True)
class VersionRequest:
    pass

class ToolRegistryClient:
    def __init__(
        self,
        base_url: str | None = None,
        *,
        client: _LowLevelClient | None = None,
        timeout: httpx.Timeout | None = None,
        headers: dict[str, str] | None = None,
        cookies: dict[str, str] | None = None,
        verify_ssl: Any = True,
        follow_redirects: bool = False,
        raise_on_unexpected_status: bool = False,
        httpx_args: dict[str, Any] | None = None,
    ) -> None:
        if client is None:
            if base_url is None:
                raise ValueError("base_url is required when client is not provided")
            client = _LowLevelClient(
                base_url=base_url,
                timeout=timeout,
                headers={} if headers is None else dict(headers),
                cookies={} if cookies is None else dict(cookies),
                verify_ssl=verify_ssl,
                follow_redirects=follow_redirects,
                raise_on_unexpected_status=raise_on_unexpected_status,
                httpx_args={} if httpx_args is None else dict(httpx_args),
            )
        self._client = client

    @property
    def raw_client(self) -> _LowLevelClient:
        return self._client

    @overload
    def get_tool(self, tool_id: str) -> ToolDefinition: ...

    @overload
    def get_tool(self, tool_id: GetToolRequest) -> ToolDefinition: ...

    def get_tool(self, tool_id: GetToolRequest | str) -> ToolDefinition:
        value = tool_id.tool_id if isinstance(tool_id, GetToolRequest) else tool_id
        tool_id = value
        resp = get_tool.sync_detailed(client=self._client, tool_id=tool_id)
        result = _unwrap(resp)
        return result

    @overload
    def health(self) -> Health: ...

    @overload
    def health(self, request: HealthRequest) -> Health: ...

    def health(self, request: HealthRequest | None = None) -> Health:
        _ = request
        resp = health.sync_detailed(client=self._client)
        return _unwrap(resp)

    def invoke_tool(self, request: InvokeToolRequest) -> ToolInvocationResult:
        body = request.to_body()
        resp = invoke_tool.sync_detailed(client=self._client, body=body)
        result = _unwrap(resp)
        return result

    @overload
    def list_tools(self) -> list[ToolDefinition]: ...

    @overload
    def list_tools(self, request: ListToolsRequest) -> list[ToolDefinition]: ...

    def list_tools(self, request: ListToolsRequest | None = None) -> list[ToolDefinition]:
        _ = request
        resp = list_tools.sync_detailed(client=self._client)
        return _unwrap(resp)

    @overload
    def version(self) -> VersionInfo: ...

    @overload
    def version(self, request: VersionRequest) -> VersionInfo: ...

    def version(self, request: VersionRequest | None = None) -> VersionInfo:
        _ = request
        resp = version.sync_detailed(client=self._client)
        return _unwrap(resp)

__all__ = [
    'ToolRegistryClient',
    'GetToolRequest',
    'HealthRequest',
    'InvokeToolRequest',
    'ListToolsRequest',
    'VersionRequest',
]



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.instance_create_request_metadata import InstanceCreateRequestMetadata
  from ..models.instance_create_request_extensions import InstanceCreateRequestExtensions
  from ..models.instance_create_request_overrides import InstanceCreateRequestOverrides





T = TypeVar("T", bound="InstanceCreateRequest")



@_attrs_define
class InstanceCreateRequest:
    """ 
        Attributes:
            runtime_profile (str):
            count (int | Unset):  Default: 1.
            extensions (InstanceCreateRequestExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            metadata (InstanceCreateRequestMetadata | Unset):
            overrides (InstanceCreateRequestOverrides | Unset):
     """

    runtime_profile: str
    count: int | Unset = 1
    extensions: InstanceCreateRequestExtensions | Unset = UNSET
    metadata: InstanceCreateRequestMetadata | Unset = UNSET
    overrides: InstanceCreateRequestOverrides | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.instance_create_request_metadata import InstanceCreateRequestMetadata
        from ..models.instance_create_request_extensions import InstanceCreateRequestExtensions
        from ..models.instance_create_request_overrides import InstanceCreateRequestOverrides
        runtime_profile = self.runtime_profile

        count = self.count

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        overrides: dict[str, Any] | Unset = UNSET
        if not isinstance(self.overrides, Unset):
            overrides = self.overrides.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "runtime_profile": runtime_profile,
        })
        if count is not UNSET:
            field_dict["count"] = count
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if overrides is not UNSET:
            field_dict["overrides"] = overrides

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.instance_create_request_metadata import InstanceCreateRequestMetadata
        from ..models.instance_create_request_extensions import InstanceCreateRequestExtensions
        from ..models.instance_create_request_overrides import InstanceCreateRequestOverrides
        d = dict(src_dict)
        runtime_profile = d.pop("runtime_profile")

        count = d.pop("count", UNSET)

        _extensions = d.pop("extensions", UNSET)
        extensions: InstanceCreateRequestExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = InstanceCreateRequestExtensions.from_dict(_extensions)




        _metadata = d.pop("metadata", UNSET)
        metadata: InstanceCreateRequestMetadata | Unset
        if isinstance(_metadata,  Unset):
            metadata = UNSET
        else:
            metadata = InstanceCreateRequestMetadata.from_dict(_metadata)




        _overrides = d.pop("overrides", UNSET)
        overrides: InstanceCreateRequestOverrides | Unset
        if isinstance(_overrides,  Unset):
            overrides = UNSET
        else:
            overrides = InstanceCreateRequestOverrides.from_dict(_overrides)




        instance_create_request = cls(
            runtime_profile=runtime_profile,
            count=count,
            extensions=extensions,
            metadata=metadata,
            overrides=overrides,
        )

        return instance_create_request




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset






T = TypeVar("T", bound="RunRequestLimits")



@_attrs_define
class RunRequestLimits:
    """ 
        Attributes:
            max_steps (int | Unset):
            max_tokens (int | Unset):
            timeout_ms (int | Unset):
     """

    max_steps: int | Unset = UNSET
    max_tokens: int | Unset = UNSET
    timeout_ms: int | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        max_steps = self.max_steps

        max_tokens = self.max_tokens

        timeout_ms = self.timeout_ms


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if max_steps is not UNSET:
            field_dict["max_steps"] = max_steps
        if max_tokens is not UNSET:
            field_dict["max_tokens"] = max_tokens
        if timeout_ms is not UNSET:
            field_dict["timeout_ms"] = timeout_ms

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        max_steps = d.pop("max_steps", UNSET)

        max_tokens = d.pop("max_tokens", UNSET)

        timeout_ms = d.pop("timeout_ms", UNSET)

        run_request_limits = cls(
            max_steps=max_steps,
            max_tokens=max_tokens,
            timeout_ms=timeout_ms,
        )

        return run_request_limits




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.run_list_response_run_status_state import RunListResponseRunStatusState
from ..types import UNSET, Unset
from dateutil.parser import isoparse
from typing import cast
import datetime

if TYPE_CHECKING:
  from ..models.run_list_response_run_status_extensions import RunListResponseRunStatusExtensions





T = TypeVar("T", bound="RunListResponseRunStatus")



@_attrs_define
class RunListResponseRunStatus:
    """ 
        Attributes:
            run_id (str):
            state (RunListResponseRunStatusState):
            ended_at (datetime.datetime | Unset):
            extensions (RunListResponseRunStatusExtensions | Unset): Optional vendor extension map. Keys must be namespaced
                as <reverse_dns_or_org>.<key>.
            runtime_instance_id (str | Unset):
            started_at (datetime.datetime | Unset):
     """

    run_id: str
    state: RunListResponseRunStatusState
    ended_at: datetime.datetime | Unset = UNSET
    extensions: RunListResponseRunStatusExtensions | Unset = UNSET
    runtime_instance_id: str | Unset = UNSET
    started_at: datetime.datetime | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_list_response_run_status_extensions import RunListResponseRunStatusExtensions
        run_id = self.run_id

        state = self.state.value

        ended_at: str | Unset = UNSET
        if not isinstance(self.ended_at, Unset):
            ended_at = self.ended_at.isoformat()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        runtime_instance_id = self.runtime_instance_id

        started_at: str | Unset = UNSET
        if not isinstance(self.started_at, Unset):
            started_at = self.started_at.isoformat()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "run_id": run_id,
            "state": state,
        })
        if ended_at is not UNSET:
            field_dict["ended_at"] = ended_at
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if runtime_instance_id is not UNSET:
            field_dict["runtime_instance_id"] = runtime_instance_id
        if started_at is not UNSET:
            field_dict["started_at"] = started_at

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_list_response_run_status_extensions import RunListResponseRunStatusExtensions
        d = dict(src_dict)
        run_id = d.pop("run_id")

        state = RunListResponseRunStatusState(d.pop("state"))




        _ended_at = d.pop("ended_at", UNSET)
        ended_at: datetime.datetime | Unset
        if isinstance(_ended_at,  Unset):
            ended_at = UNSET
        else:
            ended_at = isoparse(_ended_at)




        _extensions = d.pop("extensions", UNSET)
        extensions: RunListResponseRunStatusExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RunListResponseRunStatusExtensions.from_dict(_extensions)




        runtime_instance_id = d.pop("runtime_instance_id", UNSET)

        _started_at = d.pop("started_at", UNSET)
        started_at: datetime.datetime | Unset
        if isinstance(_started_at,  Unset):
            started_at = UNSET
        else:
            started_at = isoparse(_started_at)




        run_list_response_run_status = cls(
            run_id=run_id,
            state=state,
            ended_at=ended_at,
            extensions=extensions,
            runtime_instance_id=runtime_instance_id,
            started_at=started_at,
        )

        return run_list_response_run_status




from enum import Enum

class InstanceListResponseRuntimeInstanceState(str, Enum):
    BUSY = "busy"
    ERROR = "error"
    READY = "ready"
    STARTING = "starting"
    STOPPED = "stopped"
    STOPPING = "stopping"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class TraceResponseTraceEventLevel(str, Enum):
    DEBUG = "debug"
    ERROR = "error"
    INFO = "info"
    WARN = "warn"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.tool_definition_source import ToolDefinitionSource
from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.tool_definition_extensions import ToolDefinitionExtensions
  from ..models.tool_definition_output_schema import ToolDefinitionOutputSchema
  from ..models.tool_definition_input_schema import ToolDefinitionInputSchema
  from ..models.tool_definition_metadata import ToolDefinitionMetadata





T = TypeVar("T", bound="ToolDefinition")



@_attrs_define
class ToolDefinition:
    """ 
        Attributes:
            input_schema (ToolDefinitionInputSchema):
            name (str):
            source (ToolDefinitionSource):
            tool_id (str):
            description (str | Unset):
            extensions (ToolDefinitionExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            metadata (ToolDefinitionMetadata | Unset):
            output_schema (ToolDefinitionOutputSchema | Unset):
     """

    input_schema: ToolDefinitionInputSchema
    name: str
    source: ToolDefinitionSource
    tool_id: str
    description: str | Unset = UNSET
    extensions: ToolDefinitionExtensions | Unset = UNSET
    metadata: ToolDefinitionMetadata | Unset = UNSET
    output_schema: ToolDefinitionOutputSchema | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.tool_definition_extensions import ToolDefinitionExtensions
        from ..models.tool_definition_output_schema import ToolDefinitionOutputSchema
        from ..models.tool_definition_input_schema import ToolDefinitionInputSchema
        from ..models.tool_definition_metadata import ToolDefinitionMetadata
        input_schema = self.input_schema.to_dict()

        name = self.name

        source = self.source.value

        tool_id = self.tool_id

        description = self.description

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        output_schema: dict[str, Any] | Unset = UNSET
        if not isinstance(self.output_schema, Unset):
            output_schema = self.output_schema.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "input_schema": input_schema,
            "name": name,
            "source": source,
            "tool_id": tool_id,
        })
        if description is not UNSET:
            field_dict["description"] = description
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if output_schema is not UNSET:
            field_dict["output_schema"] = output_schema

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.tool_definition_extensions import ToolDefinitionExtensions
        from ..models.tool_definition_output_schema import ToolDefinitionOutputSchema
        from ..models.tool_definition_input_schema import ToolDefinitionInputSchema
        from ..models.tool_definition_metadata import ToolDefinitionMetadata
        d = dict(src_dict)
        input_schema = ToolDefinitionInputSchema.from_dict(d.pop("input_schema"))




        name = d.pop("name")

        source = ToolDefinitionSource(d.pop("source"))




        tool_id = d.pop("tool_id")

        description = d.pop("description", UNSET)

        _extensions = d.pop("extensions", UNSET)
        extensions: ToolDefinitionExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = ToolDefinitionExtensions.from_dict(_extensions)




        _metadata = d.pop("metadata", UNSET)
        metadata: ToolDefinitionMetadata | Unset
        if isinstance(_metadata,  Unset):
            metadata = UNSET
        else:
            metadata = ToolDefinitionMetadata.from_dict(_metadata)




        _output_schema = d.pop("output_schema", UNSET)
        output_schema: ToolDefinitionOutputSchema | Unset
        if isinstance(_output_schema,  Unset):
            output_schema = UNSET
        else:
            output_schema = ToolDefinitionOutputSchema.from_dict(_output_schema)




        tool_definition = cls(
            input_schema=input_schema,
            name=name,
            source=source,
            tool_id=tool_id,
            description=description,
            extensions=extensions,
            metadata=metadata,
            output_schema=output_schema,
        )

        return tool_definition




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_profile_list_response_runtime_profile_metadata_labels import RuntimeProfileListResponseRuntimeProfileMetadataLabels
  from ..models.runtime_profile_list_response_runtime_profile_metadata_annotations import RuntimeProfileListResponseRuntimeProfileMetadataAnnotations
  from ..models.runtime_profile_list_response_runtime_profile_metadata_extensions import RuntimeProfileListResponseRuntimeProfileMetadataExtensions





T = TypeVar("T", bound="RuntimeProfileListResponseRuntimeProfileMetadata")



@_attrs_define
class RuntimeProfileListResponseRuntimeProfileMetadata:
    """ 
        Attributes:
            annotations (RuntimeProfileListResponseRuntimeProfileMetadataAnnotations | Unset):
            extensions (RuntimeProfileListResponseRuntimeProfileMetadataExtensions | Unset): Optional vendor extension map.
                Keys must be namespaced as <reverse_dns_or_org>.<key>.
            labels (RuntimeProfileListResponseRuntimeProfileMetadataLabels | Unset):
     """

    annotations: RuntimeProfileListResponseRuntimeProfileMetadataAnnotations | Unset = UNSET
    extensions: RuntimeProfileListResponseRuntimeProfileMetadataExtensions | Unset = UNSET
    labels: RuntimeProfileListResponseRuntimeProfileMetadataLabels | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_profile_list_response_runtime_profile_metadata_labels import RuntimeProfileListResponseRuntimeProfileMetadataLabels
        from ..models.runtime_profile_list_response_runtime_profile_metadata_annotations import RuntimeProfileListResponseRuntimeProfileMetadataAnnotations
        from ..models.runtime_profile_list_response_runtime_profile_metadata_extensions import RuntimeProfileListResponseRuntimeProfileMetadataExtensions
        annotations: dict[str, Any] | Unset = UNSET
        if not isinstance(self.annotations, Unset):
            annotations = self.annotations.to_dict()

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        labels: dict[str, Any] | Unset = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if annotations is not UNSET:
            field_dict["annotations"] = annotations
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if labels is not UNSET:
            field_dict["labels"] = labels

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_profile_list_response_runtime_profile_metadata_labels import RuntimeProfileListResponseRuntimeProfileMetadataLabels
        from ..models.runtime_profile_list_response_runtime_profile_metadata_annotations import RuntimeProfileListResponseRuntimeProfileMetadataAnnotations
        from ..models.runtime_profile_list_response_runtime_profile_metadata_extensions import RuntimeProfileListResponseRuntimeProfileMetadataExtensions
        d = dict(src_dict)
        _annotations = d.pop("annotations", UNSET)
        annotations: RuntimeProfileListResponseRuntimeProfileMetadataAnnotations | Unset
        if isinstance(_annotations,  Unset):
            annotations = UNSET
        else:
            annotations = RuntimeProfileListResponseRuntimeProfileMetadataAnnotations.from_dict(_annotations)




        _extensions = d.pop("extensions", UNSET)
        extensions: RuntimeProfileListResponseRuntimeProfileMetadataExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RuntimeProfileListResponseRuntimeProfileMetadataExtensions.from_dict(_extensions)




        _labels = d.pop("labels", UNSET)
        labels: RuntimeProfileListResponseRuntimeProfileMetadataLabels | Unset
        if isinstance(_labels,  Unset):
            labels = UNSET
        else:
            labels = RuntimeProfileListResponseRuntimeProfileMetadataLabels.from_dict(_labels)




        runtime_profile_list_response_runtime_profile_metadata = cls(
            annotations=annotations,
            extensions=extensions,
            labels=labels,
        )

        return runtime_profile_list_response_runtime_profile_metadata




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.run_result_resource_ref_extensions import RunResultResourceRefExtensions





T = TypeVar("T", bound="RunResultResourceRef")



@_attrs_define
class RunResultResourceRef:
    """ 
        Attributes:
            id (str):
            type_ (str):
            extensions (RunResultResourceRefExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            uri (str | Unset):
     """

    id: str
    type_: str
    extensions: RunResultResourceRefExtensions | Unset = UNSET
    uri: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_result_resource_ref_extensions import RunResultResourceRefExtensions
        id = self.id

        type_ = self.type_

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        uri = self.uri


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "id": id,
            "type": type_,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if uri is not UNSET:
            field_dict["uri"] = uri

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_result_resource_ref_extensions import RunResultResourceRefExtensions
        d = dict(src_dict)
        id = d.pop("id")

        type_ = d.pop("type")

        _extensions = d.pop("extensions", UNSET)
        extensions: RunResultResourceRefExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RunResultResourceRefExtensions.from_dict(_extensions)




        uri = d.pop("uri", UNSET)

        run_result_resource_ref = cls(
            id=id,
            type_=type_,
            extensions=extensions,
            uri=uri,
        )

        return run_result_resource_ref




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.run_request_input_context import RunRequestInputContext
  from ..models.run_request_input_data import RunRequestInputData





T = TypeVar("T", bound="RunRequestInput")



@_attrs_define
class RunRequestInput:
    """ 
        Attributes:
            goal (str):
            context (RunRequestInputContext | Unset):
            data (RunRequestInputData | Unset):
     """

    goal: str
    context: RunRequestInputContext | Unset = UNSET
    data: RunRequestInputData | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_request_input_context import RunRequestInputContext
        from ..models.run_request_input_data import RunRequestInputData
        goal = self.goal

        context: dict[str, Any] | Unset = UNSET
        if not isinstance(self.context, Unset):
            context = self.context.to_dict()

        data: dict[str, Any] | Unset = UNSET
        if not isinstance(self.data, Unset):
            data = self.data.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "goal": goal,
        })
        if context is not UNSET:
            field_dict["context"] = context
        if data is not UNSET:
            field_dict["data"] = data

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_request_input_context import RunRequestInputContext
        from ..models.run_request_input_data import RunRequestInputData
        d = dict(src_dict)
        goal = d.pop("goal")

        _context = d.pop("context", UNSET)
        context: RunRequestInputContext | Unset
        if isinstance(_context,  Unset):
            context = UNSET
        else:
            context = RunRequestInputContext.from_dict(_context)




        _data = d.pop("data", UNSET)
        data: RunRequestInputData | Unset
        if isinstance(_data,  Unset):
            data = UNSET
        else:
            data = RunRequestInputData.from_dict(_data)




        run_request_input = cls(
            goal=goal,
            context=context,
            data=data,
        )

        return run_request_input




from enum import Enum

class RunListResponseRunStatusState(str, Enum):
    CANCELED = "canceled"
    FAILED = "failed"
    QUEUED = "queued"
    RUNNING = "running"
    SUCCEEDED = "succeeded"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.runtime_instance_state import RuntimeInstanceState
from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.runtime_instance_extensions import RuntimeInstanceExtensions
  from ..models.runtime_instance_metadata import RuntimeInstanceMetadata





T = TypeVar("T", bound="RuntimeInstance")



@_attrs_define
class RuntimeInstance:
    """ 
        Attributes:
            instance_id (str):
            runtime_api_endpoint (str): Transport-agnostic locator URI for an API endpoint (e.g. http://127.0.0.1:43120).
                Future deployments may use other URI schemes (e.g. unix://...).
            state (RuntimeInstanceState):
            extensions (RuntimeInstanceExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            managed (bool | Unset):  Default: True.
            metadata (RuntimeInstanceMetadata | Unset):
            runtime_name (str | Unset):
            runtime_profile (str | Unset):
            runtime_version (str | Unset):
     """

    instance_id: str
    runtime_api_endpoint: str
    state: RuntimeInstanceState
    extensions: RuntimeInstanceExtensions | Unset = UNSET
    managed: bool | Unset = True
    metadata: RuntimeInstanceMetadata | Unset = UNSET
    runtime_name: str | Unset = UNSET
    runtime_profile: str | Unset = UNSET
    runtime_version: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.runtime_instance_extensions import RuntimeInstanceExtensions
        from ..models.runtime_instance_metadata import RuntimeInstanceMetadata
        instance_id = self.instance_id

        runtime_api_endpoint = self.runtime_api_endpoint

        state = self.state.value

        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        managed = self.managed

        metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        runtime_name = self.runtime_name

        runtime_profile = self.runtime_profile

        runtime_version = self.runtime_version


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "instance_id": instance_id,
            "runtime_api_endpoint": runtime_api_endpoint,
            "state": state,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if managed is not UNSET:
            field_dict["managed"] = managed
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if runtime_name is not UNSET:
            field_dict["runtime_name"] = runtime_name
        if runtime_profile is not UNSET:
            field_dict["runtime_profile"] = runtime_profile
        if runtime_version is not UNSET:
            field_dict["runtime_version"] = runtime_version

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.runtime_instance_extensions import RuntimeInstanceExtensions
        from ..models.runtime_instance_metadata import RuntimeInstanceMetadata
        d = dict(src_dict)
        instance_id = d.pop("instance_id")

        runtime_api_endpoint = d.pop("runtime_api_endpoint")

        state = RuntimeInstanceState(d.pop("state"))




        _extensions = d.pop("extensions", UNSET)
        extensions: RuntimeInstanceExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RuntimeInstanceExtensions.from_dict(_extensions)




        managed = d.pop("managed", UNSET)

        _metadata = d.pop("metadata", UNSET)
        metadata: RuntimeInstanceMetadata | Unset
        if isinstance(_metadata,  Unset):
            metadata = UNSET
        else:
            metadata = RuntimeInstanceMetadata.from_dict(_metadata)




        runtime_name = d.pop("runtime_name", UNSET)

        runtime_profile = d.pop("runtime_profile", UNSET)

        runtime_version = d.pop("runtime_version", UNSET)

        runtime_instance = cls(
            instance_id=instance_id,
            runtime_api_endpoint=runtime_api_endpoint,
            state=state,
            extensions=extensions,
            managed=managed,
            metadata=metadata,
            runtime_name=runtime_name,
            runtime_profile=runtime_profile,
            runtime_version=runtime_version,
        )

        return runtime_instance




from __future__ import annotations

from arp_sdk.daemon.models import (
    InstanceCreateRequest,
    InstanceCreateResponse,
    InstanceListResponse,
    InstanceRegisterRequest,
    InstanceRegisterResponse,
    RunListResponse,
    RuntimeProfile,
    RuntimeProfileListResponse,
    RuntimeProfileUpsertRequest,
    RuntimeInstance,
    TraceResponse,
)
from arp_sdk.runtime.models import RunRequest, RunResult, RunStatus
from arp_sdk.tool_registry.models import ToolDefinition, ToolInvocationResult

__all__ = [
    "InstanceCreateRequest",
    "InstanceCreateResponse",
    "InstanceListResponse",
    "InstanceRegisterRequest",
    "InstanceRegisterResponse",
    "RunListResponse",
    "RuntimeProfile",
    "RuntimeProfileListResponse",
    "RuntimeProfileUpsertRequest",
    "RuntimeInstance",
    "RunRequest",
    "RunResult",
    "RunStatus",
    "ToolDefinition",
    "ToolInvocationResult",
    "TraceResponse",
]



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.run_list_response_pagination import RunListResponsePagination
  from ..models.run_list_response_extensions import RunListResponseExtensions
  from ..models.run_list_response_run_status import RunListResponseRunStatus





T = TypeVar("T", bound="RunListResponse")



@_attrs_define
class RunListResponse:
    """ 
        Attributes:
            runs (list[RunListResponseRunStatus]):
            extensions (RunListResponseExtensions | Unset): Optional vendor extension map. Keys must be namespaced as
                <reverse_dns_or_org>.<key>.
            pagination (RunListResponsePagination | Unset):
     """

    runs: list[RunListResponseRunStatus]
    extensions: RunListResponseExtensions | Unset = UNSET
    pagination: RunListResponsePagination | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        from ..models.run_list_response_pagination import RunListResponsePagination
        from ..models.run_list_response_extensions import RunListResponseExtensions
        from ..models.run_list_response_run_status import RunListResponseRunStatus
        runs = []
        for runs_item_data in self.runs:
            runs_item = runs_item_data.to_dict()
            runs.append(runs_item)



        extensions: dict[str, Any] | Unset = UNSET
        if not isinstance(self.extensions, Unset):
            extensions = self.extensions.to_dict()

        pagination: dict[str, Any] | Unset = UNSET
        if not isinstance(self.pagination, Unset):
            pagination = self.pagination.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "runs": runs,
        })
        if extensions is not UNSET:
            field_dict["extensions"] = extensions
        if pagination is not UNSET:
            field_dict["pagination"] = pagination

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_list_response_pagination import RunListResponsePagination
        from ..models.run_list_response_extensions import RunListResponseExtensions
        from ..models.run_list_response_run_status import RunListResponseRunStatus
        d = dict(src_dict)
        runs = []
        _runs = d.pop("runs")
        for runs_item_data in (_runs):
            runs_item = RunListResponseRunStatus.from_dict(runs_item_data)



            runs.append(runs_item)


        _extensions = d.pop("extensions", UNSET)
        extensions: RunListResponseExtensions | Unset
        if isinstance(_extensions,  Unset):
            extensions = UNSET
        else:
            extensions = RunListResponseExtensions.from_dict(_extensions)




        _pagination = d.pop("pagination", UNSET)
        pagination: RunListResponsePagination | Unset
        if isinstance(_pagination,  Unset):
            pagination = UNSET
        else:
            pagination = RunListResponsePagination.from_dict(_pagination)




        run_list_response = cls(
            runs=runs,
            extensions=extensions,
            pagination=pagination,
        )

        return run_list_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset






T = TypeVar("T", bound="RunRequestRuntimeSelector")



@_attrs_define
class RunRequestRuntimeSelector:
    """ 
        Attributes:
            instance_id (str | Unset):
            runtime_api_endpoint (str | Unset): Transport-agnostic locator URI for an API endpoint (e.g.
                http://127.0.0.1:43120). Future deployments may use other URI schemes (e.g. unix://...).
            runtime_name (str | Unset):
            runtime_profile (str | Unset):
     """

    instance_id: str | Unset = UNSET
    runtime_api_endpoint: str | Unset = UNSET
    runtime_name: str | Unset = UNSET
    runtime_profile: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        instance_id = self.instance_id

        runtime_api_endpoint = self.runtime_api_endpoint

        runtime_name = self.runtime_name

        runtime_profile = self.runtime_profile


        field_dict: dict[str, Any] = {}

        field_dict.update({
        })
        if instance_id is not UNSET:
            field_dict["instance_id"] = instance_id
        if runtime_api_endpoint is not UNSET:
            field_dict["runtime_api_endpoint"] = runtime_api_endpoint
        if runtime_name is not UNSET:
            field_dict["runtime_name"] = runtime_name
        if runtime_profile is not UNSET:
            field_dict["runtime_profile"] = runtime_profile

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        instance_id = d.pop("instance_id", UNSET)

        runtime_api_endpoint = d.pop("runtime_api_endpoint", UNSET)

        runtime_name = d.pop("runtime_name", UNSET)

        runtime_profile = d.pop("runtime_profile", UNSET)

        run_request_runtime_selector = cls(
            instance_id=instance_id,
            runtime_api_endpoint=runtime_api_endpoint,
            runtime_name=runtime_name,
            runtime_profile=runtime_profile,
        )

        return run_request_runtime_selector

